@@ -11,8 +11,8 @@
 #ifndef __E_BOOK_H__
 #define __E_BOOK_H__
 
-#include <glib.h>
-#include <glib-object.h>
+/* e-book deprecated since 3.2, use e-book-client instead */
+#ifndef E_BOOK_DISABLE_DEPRECATED
 
 #include "libedataserver/e-list.h"
 #include "libedataserver/e-source.h"
@@ -411,4 +411,6 @@ GType        e_book_get_type                  (void);
 
 G_END_DECLS
 
+#endif /* E_BOOK_DISABLE_DEPRECATED */
+
 #endif /* __E_BOOK_H__ */
