@@ -24,7 +24,6 @@
 #include <config.h>
 #endif
 
-#include <glib.h>
 #include <stdio.h>
 #include <ctype.h>
 #include <string.h>
@@ -493,7 +492,7 @@ photo_setter (EContact *contact, EVCardAttribute *attr, gpointer data)
 							e_vcard_attribute_param_new (EVC_TYPE),
 							image_type);
 
-		e_vcard_attribute_add_value_decoded (attr, (gchar *)photo->data.inlined.data, photo->data.inlined.length);
+		e_vcard_attribute_add_value_decoded (attr, (gchar *) photo->data.inlined.data, photo->data.inlined.length);
 		break;
 	case E_CONTACT_PHOTO_TYPE_URI:
 		e_vcard_attribute_add_param_with_value (attr,
@@ -529,7 +528,7 @@ fn_setter (EContact *contact, EVCardAttribute *attr, gpointer data)
 
 	attr = e_contact_get_first_attr (contact, EVC_N);
 	if (!attr) {
-		EContactName *name = e_contact_name_from_string ((gchar *)data);
+		EContactName *name = e_contact_name_from_string ((gchar *) data);
 
 		attr = e_vcard_attribute_new (NULL, EVC_N);
 		e_vcard_append_attribute (E_VCARD (contact), attr);
@@ -748,7 +747,7 @@ e_contact_set_property (GObject *object,
 		for (l = new_values; l; l = l->next)
 			e_vcard_append_attribute_with_value (E_VCARD (contact),
 							  e_vcard_attribute_new (NULL, info->vcard_field_name),
-							  (gchar *)l->data);
+							  (gchar *) l->data);
 	}
 	else if (info->t & E_CONTACT_FIELD_TYPE_SYNTHETIC) {
 		if (info->t & E_CONTACT_FIELD_TYPE_MULTI_ELEM) {
@@ -841,11 +840,11 @@ e_contact_set_property (GObject *object,
 							GList *values = e_vcard_attribute_param_get_values (param);
 
 							while (values && values->data) {
-								if (!found_needed1 && !g_ascii_strcasecmp ((gchar *)values->data, info->attr_type1)) {
+								if (!found_needed1 && !g_ascii_strcasecmp ((gchar *) values->data, info->attr_type1)) {
 									found_needed1 = TRUE;
 									matches = TRUE;
 								}
-								else if (!found_needed2 && !g_ascii_strcasecmp ((gchar *)values->data, info->attr_type2)) {
+								else if (!found_needed2 && !g_ascii_strcasecmp ((gchar *) values->data, info->attr_type2)) {
 									found_needed2 = TRUE;
 									matches = TRUE;
 								} else if (found_needed1) {
@@ -894,10 +893,10 @@ e_contact_set_property (GObject *object,
 			}
 
 			if (info->t & E_CONTACT_FIELD_TYPE_STRUCT || info->t & E_CONTACT_FIELD_TYPE_GETSET) {
-				gpointer data = info->t & E_CONTACT_FIELD_TYPE_STRUCT ? g_value_get_boxed (value) : (gchar *)g_value_get_string (value);
+				gpointer data = info->t & E_CONTACT_FIELD_TYPE_STRUCT ? g_value_get_boxed (value) : (gchar *) g_value_get_string (value);
 
 				if ((info->t & E_CONTACT_FIELD_TYPE_STRUCT && data)
-				    || (data && *(gchar *)data))
+				    || (data && *(gchar *) data))
 					info->struct_setter (contact, attr, data);
 				else
 					e_vcard_remove_attribute (E_VCARD (contact), attr);
@@ -985,11 +984,11 @@ e_contact_set_property (GObject *object,
 	}
 	else if (info->t & E_CONTACT_FIELD_TYPE_STRUCT || info->t & E_CONTACT_FIELD_TYPE_GETSET) {
 		EVCardAttribute *attr = e_contact_get_first_attr (contact, info->vcard_field_name);
-		gpointer data = info->t & E_CONTACT_FIELD_TYPE_STRUCT ? g_value_get_boxed (value) : (gchar *)g_value_get_string (value);
+		gpointer data = info->t & E_CONTACT_FIELD_TYPE_STRUCT ? g_value_get_boxed (value) : (gchar *) g_value_get_string (value);
 
 		if (attr) {
 			if ((info->t & E_CONTACT_FIELD_TYPE_STRUCT && data)
-			    || (data && *(gchar *)data)) {
+			    || (data && *(gchar *) data)) {
 				d(printf ("overwriting existing %s\n", info->vcard_field_name));
 				/* remove all existing values and parameters.
 				   the setter will add the correct ones */
@@ -1005,7 +1004,7 @@ e_contact_set_property (GObject *object,
 			}
 		}
 		else if ((info->t & E_CONTACT_FIELD_TYPE_STRUCT && data)
-			 || (data && *(gchar *)data)) {
+			 || (data && *(gchar *) data)) {
 			d(printf ("adding new %s\n", info->vcard_field_name));
 			attr = e_vcard_attribute_new (NULL, info->vcard_field_name);
 
@@ -1113,11 +1112,11 @@ e_contact_find_attribute_with_types (EContact *contact, const gchar *attr_name,
 					GList *values = e_vcard_attribute_param_get_values (param);
 
 					while (values && values->data) {
-						if (!found_needed1 && !g_ascii_strcasecmp ((gchar *)values->data, type_needed1)) {
+						if (!found_needed1 && !g_ascii_strcasecmp ((gchar *) values->data, type_needed1)) {
 							found_needed1 = TRUE;
 							matches = TRUE;
 						}
-						else if (!found_needed2 && !g_ascii_strcasecmp ((gchar *)values->data, type_needed2)) {
+						else if (!found_needed2 && !g_ascii_strcasecmp ((gchar *) values->data, type_needed2)) {
 							found_needed2 = TRUE;
 							matches = TRUE;
 						} else if (found_needed1) {
@@ -1267,7 +1266,7 @@ e_contact_new_from_vcard  (const gchar *vcard)
  *
  * Creates a copy of @contact.
  *
- * Returns: A new #EContact identical to @contact.
+ * Returns: (transfer full): A new #EContact identical to @contact.
  **/
 EContact*
 e_contact_duplicate (EContact *contact)
@@ -1493,7 +1492,7 @@ e_contact_get (EContact *contact, EContactField field_id)
 			rv = info->struct_getter (contact, attr);
 
 		if (info->t & E_CONTACT_FIELD_TYPE_STRUCT)
-			return (gpointer)info->boxed_type_getter ();
+			return (gpointer) info->boxed_type_getter ();
 		else if (!rv)
 			return NULL;
 		else
@@ -1528,7 +1527,7 @@ e_contact_get (EContact *contact, EContactField field_id)
 				GString *str = g_string_new ("");
 				GList *v = e_vcard_attribute_get_values (attr);
 				while (v) {
-					g_string_append (str, (gchar *)v->data);
+					g_string_append (str, (gchar *) v->data);
 					v = v->next;
 					if (v)
 						g_string_append (str, ", ");
@@ -1580,7 +1579,8 @@ e_contact_get (EContact *contact, EContactField field_id)
  * Gets the value of @contact's field specified by @field_id, caching
  * the result so it can be freed later.
  *
- * Returns: Depends on the field's type, owned by the #EContact.
+ * Returns: (transfer none): Depends on the field's type, owned by the
+ * #EContact.
  **/
 gconstpointer
 e_contact_get_const (EContact *contact, EContactField field_id)
@@ -1633,7 +1633,8 @@ e_contact_set (EContact *contact, EContactField field_id, gconstpointer value)
  *
  * Gets a list of the vcard attributes for @contact's @field_id.
  *
- * Returns: (element-type EVCardAttribute) (transfer: full): A #GList of pointers to #EVCardAttribute, owned by the caller.
+ * Returns: (transfer full) (element-type EVCardAttribute): A #GList of pointers
+ * to #EVCardAttribute, owned by the caller.
  **/
 GList*
 e_contact_get_attributes (EContact *contact, EContactField field_id)
@@ -1687,7 +1688,7 @@ e_contact_set_attributes (EContact *contact, EContactField field_id, GList *attr
 
 	for (l = attributes; l; l = l->next)
 		e_vcard_append_attribute (E_VCARD (contact),
-				       e_vcard_attribute_copy ((EVCardAttribute*)l->data));
+				       e_vcard_attribute_copy ((EVCardAttribute*) l->data));
 }
 
 /**
@@ -1954,6 +1955,19 @@ e_contact_date_new (void)
 	return g_new0 (EContactDate, 1);
 }
 
+/**
+ * e_contact_photo_new:
+ *
+ * Creates a new #EContactPhoto struct.
+ *
+ * Returns: (transfer full): A new #EContactPhoto struct.
+ **/
+EContactPhoto*
+e_contact_photo_new (void)
+{
+	return g_new0 (EContactPhoto, 1);
+}
+
 /**
  * e_contact_photo_free:
  * @photo: an #EContactPhoto struct
@@ -2013,6 +2027,114 @@ e_contact_photo_copy (EContactPhoto *photo)
 	return photo2;
 }
 
+/**
+ * e_contact_photo_get_inlined:
+ * @photo: an #EContactPhoto
+ * @len: (out caller-allocates) (transfer none): the length of the inlined data
+ *
+ * Gets the @photo's data.
+ *
+ * Returns: (transfer none) (array length=len): the inlined image in the
+ * #EContactPhoto.
+ **/
+const guchar *
+e_contact_photo_get_inlined (EContactPhoto *photo, gsize *len)
+{
+	g_return_val_if_fail (photo != NULL, NULL);
+	g_return_val_if_fail (photo->type == E_CONTACT_PHOTO_TYPE_INLINED, NULL);
+
+	*len = photo->data.inlined.length;
+	return photo->data.inlined.data;
+}
+
+/**
+ * e_contact_photo_set_inlined:
+ * @photo: an #EContactPhoto
+ * @data: (transfer none) (array length=len): the inlined image data
+ * @len: the length of @data
+ *
+ * Sets the @photo's inlined data.
+ **/
+void
+e_contact_photo_set_inlined (EContactPhoto *photo,
+			     const guchar *data, gsize len)
+{
+	g_return_if_fail (photo != NULL);
+	g_return_if_fail (photo->type == E_CONTACT_PHOTO_TYPE_INLINED);
+
+	photo->data.inlined.data = g_malloc (len);
+	memcpy (photo->data.inlined.data, data, len);
+	photo->data.inlined.length = len;
+}
+
+/**
+ * e_contact_photo_get_mime_type:
+ * @photo: an #EContactPhoto
+ *
+ * Gets the @photo's mime type.
+ *
+ * Returns: (transfer none): the mime type of the image
+ **/
+const gchar *
+e_contact_photo_get_mime_type (EContactPhoto *photo)
+{
+	g_return_val_if_fail (photo != NULL, NULL);
+	g_return_val_if_fail (photo->type == E_CONTACT_PHOTO_TYPE_INLINED, NULL);
+
+	return photo->data.inlined.mime_type;
+}
+
+/**
+ * e_contact_photo_set_mime_type:
+ * @photo: an #EContactPhoto
+ * @mime_type: the mime type
+ *
+ * Sets the @photo's mime type.
+ **/
+void
+e_contact_photo_set_mime_type (EContactPhoto *photo, const gchar *mime_type)
+{
+	g_return_if_fail (photo != NULL);
+	g_return_if_fail (photo->type == E_CONTACT_PHOTO_TYPE_INLINED);
+
+	g_free (photo->data.inlined.mime_type);
+	photo->data.inlined.mime_type = g_strdup (mime_type);
+}
+
+/**
+ * e_contact_photo_get_uri:
+ * @photo: an #EContactPhoto
+ *
+ * Gets the @photo's URI.
+ *
+ * Returns: (transfer none): the URI of the image
+ **/
+const gchar *
+e_contact_photo_get_uri (EContactPhoto *photo)
+{
+	g_return_val_if_fail (photo != NULL, NULL);
+	g_return_val_if_fail (photo->type == E_CONTACT_PHOTO_TYPE_URI, NULL);
+
+	return photo->data.uri;
+}
+
+/**
+ * e_contact_photo_set_uri:
+ * @photo: an #EContactPhoto
+ * @uri: the @photo's URI
+ *
+ * Sets the @photo's URI.
+ **/
+void
+e_contact_photo_set_uri (EContactPhoto *photo, const gchar *uri)
+{
+	g_return_if_fail (photo != NULL);
+	g_return_if_fail (photo->type == E_CONTACT_PHOTO_TYPE_URI);
+
+	g_free (photo->data.uri);
+	photo->data.uri = g_strdup (uri);
+}
+
 E_CONTACT_DEFINE_BOXED_TYPE (e_contact_photo, "EContactPhoto")
 
 /**
@@ -2041,6 +2163,19 @@ e_contact_geo_copy (EContactGeo *geo)
 
 E_CONTACT_DEFINE_BOXED_TYPE (e_contact_geo, "EContactGeo")
 
+/**
+ * e_contact_address_new:
+ *
+ * Creates a new #EContactAddress struct.
+ *
+ * Returns: (transfer full): A new #EContactAddress struct.
+ **/
+EContactAddress*
+e_contact_address_new (void)
+{
+	return g_new0 (EContactAddress, 1);
+}
+
 /**
  * e_contact_address_free:
  * @address: an #EContactAddress
