@@ -41,7 +41,6 @@
 #include <string.h>
 #include <libebook/e-book.h>
 
-#include <glib.h>
 #include <libxml/xmlmemory.h>
 #include <glib/gi18n-lib.h>
 #include <camel/camel.h>
@@ -178,7 +177,7 @@ e_destination_new (void)
  *
  * Creates a new #EDestination identical to @dest.
  *
- * Returns: A newly created #EDestination, identical to @dest.
+ * Returns: (transfer full): A newly created #EDestination, identical to @dest.
  */
 EDestination*
 e_destination_copy (const EDestination *dest)
@@ -456,15 +455,18 @@ void
 e_destination_set_book (EDestination *dest, EBook *book)
 {
 	ESource *source;
+	const gchar *uid;
 
 	g_return_if_fail (dest && E_IS_DESTINATION (dest));
 	g_return_if_fail (book && E_IS_BOOK (book));
 
 	source = e_book_get_source (book);
+	uid = e_source_peek_uid (source);
+	g_return_if_fail (uid != NULL);
 
-	if (!dest->priv->source_uid || strcmp (e_source_peek_uid (source), dest->priv->source_uid)) {
+	if (!dest->priv->source_uid || strcmp (uid, dest->priv->source_uid)) {
 		e_destination_clear (dest);
-		dest->priv->source_uid = g_strdup (e_source_peek_uid (source));
+		dest->priv->source_uid = g_strdup (uid);
 
 		g_signal_emit (dest, signals[CHANGED], 0);
 	}
@@ -643,7 +645,7 @@ e_destination_set_auto_recipient (EDestination *dest, gboolean value)
  *
  * Gets the contact @dest is pointing to, if any.
  *
- * Returns: An #EContact, or %NULL if none was set.
+ * Returns: (transfer none): An #EContact, or %NULL if none was set.
  **/
 EContact *
 e_destination_get_contact (const EDestination *dest)
@@ -722,7 +724,7 @@ e_destination_get_name (const EDestination *dest)
 
 	g_return_val_if_fail (dest && E_IS_DESTINATION (dest), NULL);
 
-	priv = (struct _EDestinationPrivate *)dest->priv; /* cast out const */
+	priv = (struct _EDestinationPrivate *) dest->priv; /* cast out const */
 
 	if (priv->name == NULL) {
 		if (priv->contact != NULL) {
@@ -800,7 +802,7 @@ e_destination_get_email (const EDestination *dest)
 
 	g_return_val_if_fail (dest && E_IS_DESTINATION (dest), NULL);
 
-	priv = (struct _EDestinationPrivate *)dest->priv; /* cast out const */
+	priv = (struct _EDestinationPrivate *) dest->priv; /* cast out const */
 
 	if (priv->email == NULL) {
 		if (priv->contact != NULL) {
@@ -813,7 +815,7 @@ e_destination_get_email (const EDestination *dest)
 					priv->email = g_strdup (e);
 			}
 			if (email) {
-				g_list_foreach (email, (GFunc)g_free, NULL);
+				g_list_foreach (email, (GFunc) g_free, NULL);
 				g_list_free (email);
 			}
 
@@ -857,7 +859,7 @@ e_destination_get_address (const EDestination *dest)
 
 	g_return_val_if_fail (dest && E_IS_DESTINATION (dest), NULL);
 
-	priv = (struct _EDestinationPrivate *)dest->priv; /* cast out const */
+	priv = (struct _EDestinationPrivate *) dest->priv; /* cast out const */
 
 	if (e_destination_is_evolution_list (dest)) {
 		GList *iter = dest->priv->list_dests;
@@ -1151,14 +1153,14 @@ e_destination_xml_encode (const EDestination *dest)
 
 			str = e_destination_get_name (list_dest);
 			if (str) {
-				xmlChar *escaped = xmlEncodeEntitiesReentrant (NULL, (xmlChar*)str);
+				xmlChar *escaped = xmlEncodeEntitiesReentrant (NULL, (xmlChar*) str);
 				xmlNewTextChild (list_node, NULL, (xmlChar*)"name", escaped);
 				xmlFree (escaped);
 			}
 
 			str = e_destination_get_email (list_dest);
 			if (str) {
-				xmlChar *escaped = xmlEncodeEntitiesReentrant (NULL, (xmlChar*)str);
+				xmlChar *escaped = xmlEncodeEntitiesReentrant (NULL, (xmlChar*) str);
 				xmlNewTextChild (list_node, NULL, (xmlChar*)"email", escaped);
 				xmlFree (escaped);
 			}
@@ -1175,7 +1177,7 @@ e_destination_xml_encode (const EDestination *dest)
 
 	str = e_destination_get_source_uid (dest);
 	if (str) {
-		xmlChar *escaped = xmlEncodeEntitiesReentrant (NULL, (xmlChar*)str);
+		xmlChar *escaped = xmlEncodeEntitiesReentrant (NULL, (xmlChar*) str);
 		xmlNewTextChild (dest_node, NULL, (xmlChar*)"source_uid", escaped);
 		xmlFree (escaped);
 	}
@@ -1250,12 +1252,12 @@ e_destination_xml_decode (EDestination *dest, xmlNodePtr node)
 	node = node->xmlChildrenNode;
 	while (node) {
 		if (!strcmp ((gchar *)node->name, "name")) {
-			tmp = (gchar *)xmlNodeGetContent (node);
+			tmp = (gchar *) xmlNodeGetContent (node);
 			g_free (name);
 			name = g_strdup (tmp);
 			xmlFree (tmp);
 		} else if (!is_list && !strcmp ((gchar *)node->name, "email")) {
-			tmp = (gchar *)xmlNodeGetContent (node);
+			tmp = (gchar *) xmlNodeGetContent (node);
 			g_free (email);
 			email = g_strdup (tmp);
 			xmlFree (tmp);
@@ -1265,12 +1267,12 @@ e_destination_xml_decode (EDestination *dest, xmlNodePtr node)
 
 			while (subnode) {
 				if (!strcmp ((gchar *)subnode->name, "name")) {
-					tmp = (gchar *)xmlNodeGetContent (subnode);
+					tmp = (gchar *) xmlNodeGetContent (subnode);
 					g_free (list_name);
 					list_name = g_strdup (tmp);
 					xmlFree (tmp);
 				} else if (!strcmp ((gchar *)subnode->name, "email")) {
-					tmp = (gchar *)xmlNodeGetContent (subnode);
+					tmp = (gchar *) xmlNodeGetContent (subnode);
 					g_free (list_email);
 					list_email = g_strdup (tmp);
 					xmlFree (tmp);
@@ -1293,12 +1295,12 @@ e_destination_xml_decode (EDestination *dest, xmlNodePtr node)
 				list_dests = g_list_append (list_dests, list_dest);
 			}
 		} else if (!strcmp ((gchar *)node->name, "source_uid")) {
-			tmp = (gchar *)xmlNodeGetContent (node);
+			tmp = (gchar *) xmlNodeGetContent (node);
 			g_free (source_uid);
 			source_uid = g_strdup (tmp);
 			xmlFree (tmp);
 		} else if (!strcmp ((gchar *)node->name, "card_uid")) {
-			tmp = (gchar *)xmlNodeGetContent (node);
+			tmp = (gchar *) xmlNodeGetContent (node);
 			g_free (card_uid);
 			card_uid = g_strdup (tmp);
 			xmlFree (tmp);
@@ -1351,7 +1353,7 @@ null_terminate_and_remove_extra_whitespace (xmlChar *xml_in, gint size)
 	if (xml_in == NULL || size <= 0)
 		return NULL;
 
-	xml = g_strndup ((gchar *)xml_in, size);
+	xml = g_strndup ((gchar *) xml_in, size);
 	r = w = xml;
 
 	while (*r) {
@@ -1399,7 +1401,7 @@ e_destination_export (const EDestination *dest)
 	if (dest_node == NULL)
 		return NULL;
 
-	dest_doc = xmlNewDoc ((xmlChar*)XML_DEFAULT_VERSION);
+	dest_doc = xmlNewDoc ((xmlChar*) XML_DEFAULT_VERSION);
 	xmlDocSetRootElement (dest_doc, dest_node);
 
 	xmlDocDumpMemory (dest_doc, &buffer, &size);
@@ -1417,7 +1419,8 @@ e_destination_export (const EDestination *dest)
  *
  * Creates an #EDestination from an XML document.
  *
- * Returns: An #EDestination, or %NULL if the document was not well-formed.
+ * Returns: (transfer full): An #EDestination, or %NULL if the document was not
+ * well-formed.
  **/
 EDestination *
 e_destination_import (const gchar *str)
@@ -1461,7 +1464,7 @@ e_destination_exportv (EDestination **destv)
 	if (destv == NULL || *destv == NULL)
 		return NULL;
 
-	destv_doc  = xmlNewDoc ((xmlChar*)XML_DEFAULT_VERSION);
+	destv_doc  = xmlNewDoc ((xmlChar*) XML_DEFAULT_VERSION);
 	destv_node = xmlNewNode (NULL, (xmlChar*)"destinations");
 	xmlDocSetRootElement (destv_doc, destv_node);
 
@@ -1489,7 +1492,8 @@ e_destination_exportv (EDestination **destv)
  * Creates an array of pointers to #EDestination elements
  * from an XML document.
  *
- * Returns: A %NULL-terminated array of pointers to #EDestination elements.
+ * Returns: (transfer full):A %NULL-terminated array of pointers to
+ * #EDestination elements.
  **/
 EDestination **
 e_destination_importv (const gchar *str)
@@ -1502,7 +1506,7 @@ e_destination_importv (const gchar *str)
 	if (!(str && *str))
 		return NULL;
 
-	destv_doc = xmlParseMemory ((gchar *)str, strlen (str));
+	destv_doc = xmlParseMemory ((gchar *) str, strlen (str));
 	if (destv_doc == NULL)
 		return NULL;
 
