@@ -24,7 +24,6 @@
  * http://www.imc.org/pdi/vcard-21.txt
  */
 
-#include <glib.h>
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
@@ -73,7 +72,7 @@ e_vcard_dispose (GObject *object)
 
 	if (evc->priv) {
 
-		g_list_foreach (evc->priv->attributes, (GFunc)e_vcard_attribute_free, NULL);
+		g_list_foreach (evc->priv->attributes, (GFunc) e_vcard_attribute_free, NULL);
 		g_list_free (evc->priv->attributes);
 
 		g_free (evc->priv);
@@ -990,7 +989,7 @@ e_vcard_dump_structure (EVCard *evc)
 				printf ("    |   [%d] = %s", i,param->name);
 				printf ("(");
 				for (v = param->values; v; v = v->next) {
-					gchar *value = e_vcard_escape_string ((gchar *)v->data);
+					gchar *value = e_vcard_escape_string ((gchar *) v->data);
 					printf ("%s", value);
 					if (v->next)
 						printf (",");
@@ -1009,7 +1008,7 @@ e_vcard_dump_structure (EVCard *evc)
 
 /**
  * e_vcard_attribute_new:
- * @attr_group: a group name
+ * @attr_group: (allow-none): a group name
  * @attr_name: an attribute name
  *
  * Creates a new #EVCardAttribute with the specified group and
@@ -1078,6 +1077,24 @@ e_vcard_attribute_copy (EVCardAttribute *attr)
 	return a;
 }
 
+GType
+e_vcard_attribute_get_type (void)
+{
+	static volatile gsize type_id__volatile = 0;
+
+	if (g_once_init_enter (&type_id__volatile)) {
+		GType type_id;
+
+		type_id = g_boxed_type_register_static ("EVCardAttribute",
+							(GBoxedCopyFunc) e_vcard_attribute_copy,
+							(GBoxedFreeFunc) e_vcard_attribute_free);
+
+		g_once_init_leave (&type_id__volatile, type_id);
+	}
+
+	return type_id__volatile;
+}
+
 /**
  * e_vcard_remove_attributes:
  * @evc: vcard object
@@ -1368,11 +1385,11 @@ e_vcard_attribute_remove_values (EVCardAttribute *attr)
 {
 	g_return_if_fail (attr != NULL);
 
-	g_list_foreach (attr->values, (GFunc)g_free, NULL);
+	g_list_foreach (attr->values, (GFunc) g_free, NULL);
 	g_list_free (attr->values);
 	attr->values = NULL;
 
-	g_list_foreach (attr->decoded_values, (GFunc)free_gstring, NULL);
+	g_list_foreach (attr->decoded_values, (GFunc) free_gstring, NULL);
 	g_list_free (attr->decoded_values);
 	attr->decoded_values = NULL;
 }
@@ -1392,7 +1409,7 @@ e_vcard_attribute_remove_value (EVCardAttribute *attr, const gchar *s)
 	g_return_if_fail (attr != NULL);
 	g_return_if_fail (s != NULL);
 
-	l = g_list_find_custom (attr->values, s, (GCompareFunc)strcmp);
+	l = g_list_find_custom (attr->values, s, (GCompareFunc) strcmp);
 	if (l == NULL) {
 		return;
 	}
@@ -1440,7 +1457,7 @@ e_vcard_attribute_remove_params (EVCardAttribute *attr)
 {
 	g_return_if_fail (attr != NULL);
 
-	g_list_foreach (attr->params, (GFunc)e_vcard_attribute_param_free, NULL);
+	g_list_foreach (attr->params, (GFunc) e_vcard_attribute_param_free, NULL);
 	g_list_free (attr->params);
 	attr->params = NULL;
 
@@ -1449,6 +1466,27 @@ e_vcard_attribute_remove_params (EVCardAttribute *attr)
 	attr->encoding = EVC_ENCODING_RAW;
 }
 
+GType
+e_vcard_attribute_param_get_type (void)
+{
+	static volatile gsize type_id__volatile = 0;
+
+	if (g_once_init_enter (&type_id__volatile)) {
+		GType type_id;
+
+		type_id =
+			g_boxed_type_register_static ("EVCardAttributeParam",
+						      (GBoxedCopyFunc)
+						      e_vcard_attribute_param_copy,
+						      (GBoxedFreeFunc)
+						      e_vcard_attribute_param_free);
+
+		g_once_init_leave (&type_id__volatile, type_id);
+	}
+
+	return type_id__volatile;
+}
+
 /**
  * e_vcard_attribute_param_new:
  * @name: the name of the new parameter
@@ -1513,7 +1551,7 @@ e_vcard_attribute_param_copy (EVCardAttributeParam *param)
 /**
  * e_vcard_attribute_add_param:
  * @attr: an #EVCardAttribute
- * @param: an #EVCardAttributeParam to add
+ * @param: (transfer full): an #EVCardAttributeParam to add
  *
  * Adds @param to @attr's list of parameters.
  * It tests for duplicities, only new parameters are added,
@@ -1551,11 +1589,11 @@ e_vcard_attribute_add_param (EVCardAttribute *attr,
 				const gchar *my_value;
 				GList *vals2,*v2;
 
-				my_value = (const gchar *)v->data;
+				my_value = (const gchar *) v->data;
 				vals2 = param2->values;
 
 				for (v2 = vals2; v2; v2 = v2->next) {
-					if (g_ascii_strcasecmp ((const gchar *)v2->data, my_value) == 0) {
+					if (g_ascii_strcasecmp ((const gchar *) v2->data, my_value) == 0) {
 						break;
 					}
 				}
@@ -1590,11 +1628,11 @@ e_vcard_attribute_add_param (EVCardAttribute *attr,
 			if (!g_ascii_strcasecmp ((gchar *)param->values->data, "b") ||
 			    !g_ascii_strcasecmp ((gchar *)param->values->data, "BASE64"))
 				attr->encoding = EVC_ENCODING_BASE64;
-			else if (!g_ascii_strcasecmp ((gchar *)param->values->data, EVC_QUOTEDPRINTABLE))
+			else if (!g_ascii_strcasecmp ((gchar *) param->values->data, EVC_QUOTEDPRINTABLE))
 				attr->encoding = EVC_ENCODING_QP;
 			else {
 				g_warning ("Unknown value `%s' for ENCODING parameter.  values will be treated as raw",
-					   (gchar *)param->values->data);
+					   (gchar *) param->values->data);
 			}
 
 			attr->encoding_set = TRUE;
@@ -1711,7 +1749,7 @@ e_vcard_attribute_param_remove_values (EVCardAttributeParam *param)
 {
 	g_return_if_fail (param != NULL);
 
-	g_list_foreach (param->values, (GFunc)g_free, NULL);
+	g_list_foreach (param->values, (GFunc) g_free, NULL);
 	g_list_free (param->values);
 	param->values = NULL;
 }
@@ -1739,7 +1777,7 @@ e_vcard_attribute_remove_param_value (EVCardAttribute *attr, const gchar *param_
 	for (l = params; l; l = l->next) {
 		param = l->data;
 		if (g_ascii_strcasecmp (e_vcard_attribute_param_get_name (param), param_name) == 0) {
-			l = g_list_find_custom (param->values, s, (GCompareFunc)strcmp);
+			l = g_list_find_custom (param->values, s, (GCompareFunc) strcmp);
 			if (l == NULL) {
 				return;
 			}
@@ -1762,7 +1800,8 @@ e_vcard_attribute_remove_param_value (EVCardAttribute *attr, const gchar *param_
  * Gets the list of attributes from @evcard. The list and its
  * contents are owned by @evcard, and must not be freed.
  *
- * Returns: A list of attributes of type #EVCardAttribute.
+ * Returns: (transfer none) (element-type EVCardAttribute): A list of attributes
+ * of type #EVCardAttribute.
  **/
 GList*
 e_vcard_get_attributes (EVCard *evcard)
@@ -1842,7 +1881,7 @@ e_vcard_attribute_get_name (EVCardAttribute *attr)
  * Gets the list of values from @attr. The list and its
  * contents are owned by @attr, and must not be freed.
  *
- * Returns: A list of string values.
+ * Returns: (transfer none) (element-type utf8): A list of string values.
  **/
 GList*
 e_vcard_attribute_get_values (EVCardAttribute *attr)
@@ -1860,7 +1899,7 @@ e_vcard_attribute_get_values (EVCardAttribute *attr)
  * necessary. The list and its contents are owned by @attr,
  * and must not be freed.
  *
- * Returns: (transfer: none) (element-type: GString): A list of values of type #GString.
+ * Returns: (transfer none) (element-type GString): A list of values of type #GString.
  **/
 GList*
 e_vcard_attribute_get_values_decoded (EVCardAttribute *attr)
@@ -1872,7 +1911,7 @@ e_vcard_attribute_get_values_decoded (EVCardAttribute *attr)
 		switch (attr->encoding) {
 		case EVC_ENCODING_RAW:
 			for (l = attr->values; l; l = l->next)
-				attr->decoded_values = g_list_prepend (attr->decoded_values, g_string_new ((gchar *)l->data));
+				attr->decoded_values = g_list_prepend (attr->decoded_values, g_string_new ((gchar *) l->data));
 			attr->decoded_values = g_list_reverse (attr->decoded_values);
 			break;
 		case EVC_ENCODING_BASE64:
@@ -1935,7 +1974,7 @@ e_vcard_attribute_get_value (EVCardAttribute *attr)
 	if (!e_vcard_attribute_is_single_valued (attr))
 		g_warning ("e_vcard_attribute_get_value called on multivalued attribute");
 
-	return values ? g_strdup ((gchar *)values->data) : NULL;
+	return values ? g_strdup ((gchar *) values->data) : NULL;
 }
 
 /**
@@ -1996,7 +2035,7 @@ e_vcard_attribute_has_type (EVCardAttribute *attr, const gchar *typestr)
 			GList *v;
 
 			for (v = values; v; v = v->next) {
-				if (!g_ascii_strcasecmp ((gchar *)v->data, typestr))
+				if (!g_ascii_strcasecmp ((gchar *) v->data, typestr))
 					return TRUE;
 			}
 		}
@@ -2012,7 +2051,8 @@ e_vcard_attribute_has_type (EVCardAttribute *attr, const gchar *typestr)
  * Gets the list of parameters from @attr. The list and its
  * contents are owned by @attr, and must not be freed.
  *
- * Returns: A list of elements of type #EVCardAttributeParam.
+ * Returns: (transfer none) (element-type EVCardAttributeParam): A list of
+ * elements of type #EVCardAttributeParam.
  **/
 GList*
 e_vcard_attribute_get_params (EVCardAttribute *attr)
@@ -2030,7 +2070,8 @@ e_vcard_attribute_get_params (EVCardAttribute *attr)
  * Gets the list of values for the paramater @name from @attr. The list and its
  * contents are owned by @attr, and must not be freed.
  *
- * Returns: (transfer: none) (element-type: utf8): A list of string elements representing the parameter's values.
+ * Returns: (transfer none) (element-type utf8): A list of string elements
+ * representing the parameter's values.
  **/
 GList *
 e_vcard_attribute_get_param (EVCardAttribute *attr, const gchar *name)
@@ -2075,7 +2116,8 @@ e_vcard_attribute_param_get_name (EVCardAttributeParam *param)
  * Gets the list of values from @param. The list and its
  * contents are owned by @param, and must not be freed.
  *
- * Returns: (transfer:none) (element-type: utf8): A list of string elements representing the parameter's values.
+ * Returns: (transfer none) (element-type utf8): A list of string elements
+ * representing the parameter's values.
  **/
 GList*
 e_vcard_attribute_param_get_values (EVCardAttributeParam *param)
