@@ -24,8 +24,14 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include <glib-object.h>
 #include <glib/gi18n.h>
+
+#ifdef G_OS_UNIX
+#if GLIB_CHECK_VERSION(2,29,5)
+#include <glib-unix.h>
+#endif
+#endif
+
 #include <libebackend/e-data-server-module.h>
 #include <libebackend/e-offline-listener.h>
 #include "e-book-backend-factory.h"
@@ -33,7 +39,7 @@
 #include "e-data-book.h"
 #include "e-book-backend.h"
 
-#include "e-gdbus-egdbusbookfactory.h"
+#include "e-gdbus-book-factory.h"
 
 #ifdef G_OS_WIN32
 #include <windows.h>
@@ -84,7 +90,8 @@ struct _EDataBookFactoryPrivate {
 
 	guint exit_timeout;
 
-        gint mode;
+	/* whether should be online */
+        gboolean is_online;
 };
 
 /* Forward Declarations */
@@ -161,28 +168,27 @@ set_backend_online_status (gpointer key, gpointer value, gpointer data)
 
 	g_return_if_fail (backend != NULL);
 
-	e_book_backend_set_mode (backend,  GPOINTER_TO_INT (data));
+	e_book_backend_set_online (backend,  GPOINTER_TO_INT (data));
 }
 
 /**
- * e_data_book_factory_set_backend_mode:
+ * e_data_book_factory_set_backend_online:
  * @factory: A bookendar factory.
- * @mode: Online mode to set.
+ * @is_online: Online mode to set.
  *
  * Sets the online mode for all backends created by the given factory.
  */
 void
-e_data_book_factory_set_backend_mode (EDataBookFactory *factory,
-                                      gint mode)
+e_data_book_factory_set_backend_online (EDataBookFactory *factory, gboolean is_online)
 {
 	g_return_if_fail (E_IS_DATA_BOOK_FACTORY (factory));
 
-	factory->priv->mode = mode;
+	factory->priv->is_online = is_online;
 	g_mutex_lock (factory->priv->backends_lock);
 	g_hash_table_foreach (
 		factory->priv->backends,
 		set_backend_online_status,
-		GINT_TO_POINTER (factory->priv->mode));
+		GINT_TO_POINTER (factory->priv->is_online));
 	g_mutex_unlock (factory->priv->backends_lock);
 }
 
@@ -227,9 +233,11 @@ construct_book_factory_path (void)
 {
 	static volatile gint counter = 1;
 
+	g_atomic_int_inc (&counter);
+
 	return g_strdup_printf (
 		"/org/gnome/evolution/dataserver/AddressBook/%d/%u",
-		getpid (), g_atomic_int_exchange_and_add (&counter, 1));
+		getpid (), counter);
 }
 
 static gboolean
@@ -285,14 +293,26 @@ backend_gone_cb (EDataBookFactory *factory, GObject *dead)
 	g_mutex_unlock (priv->backends_lock);
 }
 
+static void
+last_client_gone_cb (EBookBackend *backend, EDataBookFactory *factory)
+{
+	backend_gone_cb (factory, (GObject *) backend);
+	g_object_weak_unref (G_OBJECT (backend), (GWeakNotify) backend_gone_cb, factory);
+	g_object_unref (backend);
+}
+
 static gboolean
-impl_BookFactory_getBook (EGdbusBookFactory *object, GDBusMethodInvocation *invocation, const gchar *in_source, EDataBookFactory *factory)
+impl_BookFactory_get_book (EGdbusBookFactory *object,
+                           GDBusMethodInvocation *invocation,
+                           const gchar *in_source,
+                           EDataBookFactory *factory)
 {
 	EDataBook *book;
 	EBookBackend *backend;
 	EDataBookFactoryPrivate *priv = factory->priv;
 	ESource *source;
-	gchar *uri, *path;
+	gchar *path;
+	gchar *uri;
 	const gchar *sender;
 	GList *list;
 	GError *error = NULL;
@@ -305,12 +325,6 @@ impl_BookFactory_getBook (EGdbusBookFactory *object, GDBusMethodInvocation *invo
 		return TRUE;
 	}
 
-	/* Remove a pending exit */
-	if (priv->exit_timeout) {
-		g_source_remove (priv->exit_timeout);
-		priv->exit_timeout = 0;
-	}
-
 	g_mutex_lock (priv->backends_lock);
 
 	source = e_source_new_from_standalone_xml (in_source);
@@ -350,13 +364,15 @@ impl_BookFactory_getBook (EGdbusBookFactory *object, GDBusMethodInvocation *invo
 			backend = e_book_backend_factory_new_backend (backend_factory);
 
 		if (backend != NULL) {
-			gchar *uri_key = g_strdup (uri);
-
 			g_hash_table_insert (
-				priv->backends, uri_key, backend);
-			g_object_weak_ref (G_OBJECT (backend), (GWeakNotify) backend_gone_cb, factory);
-			g_signal_connect (backend, "last-client-gone", G_CALLBACK (g_object_unref), NULL);
-			e_book_backend_set_mode (backend, priv->mode);
+				priv->backends, g_strdup (uri), backend);
+			g_object_weak_ref (
+				G_OBJECT (backend), (GWeakNotify)
+				backend_gone_cb, factory);
+			g_signal_connect (
+				backend, "last-client-gone",
+				G_CALLBACK (last_client_gone_cb), factory);
+			e_book_backend_set_online (backend, priv->is_online);
 		}
 	}
 
@@ -367,13 +383,22 @@ impl_BookFactory_getBook (EGdbusBookFactory *object, GDBusMethodInvocation *invo
 		g_mutex_unlock (priv->books_lock);
 		g_mutex_unlock (priv->backends_lock);
 
-		error = g_error_new (E_DATA_BOOK_ERROR, E_DATA_BOOK_STATUS_NO_SUCH_BOOK, _("Invalid source"));
+		error = g_error_new (
+			E_DATA_BOOK_ERROR,
+			E_DATA_BOOK_STATUS_NO_SUCH_BOOK,
+			_("Invalid source"));
 		g_dbus_method_invocation_return_gerror (invocation, error);
 		g_error_free (error);
 
 		return TRUE;
 	}
 
+	/* Remove a pending exit */
+	if (priv->exit_timeout) {
+		g_source_remove (priv->exit_timeout);
+		priv->exit_timeout = 0;
+	}
+
 	path = construct_book_factory_path ();
 	book = e_data_book_new (backend, source);
 	g_hash_table_insert (priv->books, g_strdup (path), book);
@@ -397,11 +422,10 @@ impl_BookFactory_getBook (EGdbusBookFactory *object, GDBusMethodInvocation *invo
 	g_object_unref (source);
 	g_free (uri);
 
-	if (error) {
-		g_dbus_method_invocation_return_gerror (invocation, error);
+	e_gdbus_book_factory_complete_get_book (object, invocation, path, error);
+
+	if (error)
 		g_error_free (error);
-	} else
-		e_gdbus_book_factory_complete_get_book (object, invocation, path);
 
 	g_free (path);
 
@@ -432,7 +456,7 @@ e_data_book_factory_init (EDataBookFactory *factory)
 		factory, E_TYPE_DATA_BOOK_FACTORY, EDataBookFactoryPrivate);
 
 	factory->priv->gdbus_object = e_gdbus_book_factory_stub_new ();
-	g_signal_connect (factory->priv->gdbus_object, "handle-get-book", G_CALLBACK (impl_BookFactory_getBook), factory);
+	g_signal_connect (factory->priv->gdbus_object, "handle-get-book", G_CALLBACK (impl_BookFactory_get_book), factory);
 
 	factory->priv->factories = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 
@@ -517,9 +541,7 @@ offline_state_changed_cb (EOfflineListener *eol, EDataBookFactory *factory)
 
 	g_return_if_fail (state == EOL_STATE_ONLINE || state == EOL_STATE_OFFLINE);
 
-	e_data_book_factory_set_backend_mode (
-		factory, state == EOL_STATE_ONLINE ?
-		E_DATA_BOOK_MODE_REMOTE : E_DATA_BOOK_MODE_LOCAL);
+	e_data_book_factory_set_backend_online (factory, state == EOL_STATE_ONLINE);
 }
 
 static void
@@ -574,32 +596,19 @@ on_name_lost (GDBusConnection *connection,
 	}
 
 	g_mutex_unlock (factory->priv->connections_lock);
-	g_print ("Superseded...\n");
-	g_main_loop_quit (loop);
 }
 
-#ifndef G_OS_WIN32
-static void
-quit_signal (gint sig)
+#ifdef G_OS_UNIX
+#if GLIB_CHECK_VERSION(2,29,5)
+static gboolean
+handle_term_signal (gpointer data)
 {
-	g_return_if_fail (sig == SIGQUIT);
-
-	g_print ("Received quit signal...\n");
+	g_print ("Received terminate signal...\n");
 	g_main_loop_quit (loop);
+
+	return FALSE;
 }
-
-static void
-setup_quit_signal (void)
-{
-	struct sigaction sa, osa;
-
-	sigaction (SIGQUIT, NULL, &osa);
-
-	sa.sa_flags = 0;
-	sigemptyset (&sa.sa_mask);
-	sa.sa_handler = quit_signal;
-	sigaction (SIGQUIT, &sa, NULL);
-}
+#endif
 #endif
 
 static GOptionEntry entries[] = {
@@ -667,9 +676,10 @@ main (gint argc, gchar **argv)
 		eol, "changed",
 		G_CALLBACK (offline_state_changed_cb), factory);
 
-	owner_id = g_bus_own_name (G_BUS_TYPE_SESSION,
+	owner_id = g_bus_own_name (
+		G_BUS_TYPE_SESSION,
 		ADDRESS_BOOK_DBUS_SERVICE_NAME,
-		G_BUS_NAME_OWNER_FLAGS_REPLACE | G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT,
+		G_BUS_NAME_OWNER_FLAGS_NONE,
 		on_bus_acquired,
 		on_name_acquired,
 		on_name_lost,
@@ -679,8 +689,12 @@ main (gint argc, gchar **argv)
 	/* Migrate user data from ~/.evolution to XDG base directories. */
 	e_data_book_migrate_basedir ();
 
-#ifndef G_OS_WIN32
-	setup_quit_signal ();
+#ifdef G_OS_UNIX
+#if GLIB_CHECK_VERSION(2,29,5)
+	g_unix_signal_add_watch_full (
+		SIGTERM, G_PRIORITY_DEFAULT,
+		handle_term_signal, NULL, NULL);
+#endif
 #endif
 
 	g_print ("Server is up and running...\n");
