@@ -20,12 +20,14 @@
  * Author: Ross Burton <ross@linux.intel.com>
  */
 
-#ifndef __E_DATA_BOOK_H__
-#define __E_DATA_BOOK_H__
+#ifndef E_DATA_BOOK_H
+#define E_DATA_BOOK_H
 
-#include <glib-object.h>
 #include <gio/gio.h>
+
+#include <libedataserver/e-credentials.h>
 #include <libedataserver/e-source.h>
+
 #include "e-book-backend.h"
 #include "e-data-book-types.h"
 
@@ -88,7 +90,7 @@ const gchar *e_data_book_status_to_string (EDataBookStatus status);
  **/
 #define e_return_data_book_error_if_fail(expr, _code)				\
 	G_STMT_START {								\
-		if (G_LIKELY(expr)) {						\
+		if (G_LIKELY (expr)) {						\
 		} else {							\
 			g_log (G_LOG_DOMAIN,					\
 				G_LOG_LEVEL_CRITICAL,				\
@@ -101,69 +103,55 @@ const gchar *e_data_book_status_to_string (EDataBookStatus status);
 		}								\
 	} G_STMT_END
 
-EDataBook		*e_data_book_new                    (EBookBackend *backend, ESource *source);
+/**
+ * e_return_data_book_error_if_fail:
+ *
+ * Same as e_return_data_book_error_if_fail(), only returns FALSE on a failure
+ *
+ * Since: 3.2
+ **/
+#define e_return_data_book_error_val_if_fail(expr, _code)			\
+	G_STMT_START {								\
+		if (G_LIKELY (expr)) {						\
+		} else {							\
+			g_log (G_LOG_DOMAIN,					\
+				G_LOG_LEVEL_CRITICAL,				\
+				"file %s: line %d (%s): assertion `%s' failed",	\
+				__FILE__, __LINE__, G_STRFUNC, #expr);		\
+			g_set_error (error, E_DATA_BOOK_ERROR, (_code),		\
+				"file %s: line %d (%s): assertion `%s' failed",	\
+				__FILE__, __LINE__, G_STRFUNC, #expr);		\
+			return FALSE;						\
+		}								\
+	} G_STMT_END
 
-guint			e_data_book_register_gdbus_object (EDataBook *cal, GDBusConnection *connection, const gchar *object_path, GError **error);
+GType		e_data_book_get_type				(void);
+EDataBook *	e_data_book_new					(EBookBackend *backend, ESource *source);
+EBookBackend *	e_data_book_get_backend				(EDataBook *book);
+ESource *	e_data_book_get_source				(EDataBook *book);
 
-EBookBackend		*e_data_book_get_backend            (EDataBook *book);
-ESource			*e_data_book_get_source             (EDataBook *book);
+guint		e_data_book_register_gdbus_object		(EDataBook *cal, GDBusConnection *connection, const gchar *object_path, GError **error);
 
-void                    e_data_book_respond_open           (EDataBook *book,
-							    guint32 opid,
-							    GError *error);
-void                    e_data_book_respond_remove         (EDataBook *book,
-							    guint32 opid,
-							    GError *error);
-void                    e_data_book_respond_create         (EDataBook *book,
-							    guint32 opid,
-							    GError *error,
-							    EContact *contact);
-void                    e_data_book_respond_remove_contacts (EDataBook *book,
-							     guint32 opid,
-							     GError *error,
-							     GList *ids);
-void                    e_data_book_respond_modify         (EDataBook *book,
-							    guint32 opid,
-							    GError *error,
-							    EContact *contact);
-void                    e_data_book_respond_authenticate_user (EDataBook *book,
-							       guint32 opid,
-							       GError *error);
-void                    e_data_book_respond_get_supported_fields (EDataBook *book,
-								  guint32 opid,
-								  GError *error,
-								  GList *fields);
-void                    e_data_book_respond_get_required_fields (EDataBook *book,
-								  guint32 opid,
-								  GError *error,
-								  GList *fields);
-void                    e_data_book_respond_get_supported_auth_methods (EDataBook *book,
-									guint32 opid,
-									GError *error,
-									GList *fields);
+void		e_data_book_respond_open			(EDataBook *book, guint32 opid, GError *error);
+void		e_data_book_respond_remove			(EDataBook *book, guint32 opid, GError *error);
+void		e_data_book_respond_refresh			(EDataBook *book, guint32 opid, GError *error);
+void		e_data_book_respond_get_backend_property	(EDataBook *book, guint32 opid, GError *error, const gchar *prop_value);
+void		e_data_book_respond_set_backend_property	(EDataBook *book, guint32 opid, GError *error);
+void		e_data_book_respond_create			(EDataBook *book, guint32 opid, GError *error, const EContact *contact);
+void		e_data_book_respond_remove_contacts		(EDataBook *book, guint32 opid, GError *error, const GSList *ids);
+void		e_data_book_respond_modify			(EDataBook *book, guint32 opid, GError *error, const EContact *contact);
+void		e_data_book_respond_get_contact			(EDataBook *book, guint32 opid, GError *error, const gchar *vcard);
+void		e_data_book_respond_get_contact_list		(EDataBook *book, guint32 opid, GError *error, const GSList *cards);
+void		e_data_book_respond_get_contact_list_uids	(EDataBook *book, guint32 opid, GError *error, const GSList *uids);
 
-void                    e_data_book_respond_get_contact (EDataBook *book,
-							    guint32 opid,
-							    GError *error,
-							    const gchar *vcard);
-void                    e_data_book_respond_get_contact_list (EDataBook *book,
-							      guint32 opid,
-							      GError *error,
-							      GList *cards);
-void                    e_data_book_respond_get_changes    (EDataBook *book,
-							    guint32 opid,
-							    GError *error,
-							    GList *changes);
+void		e_data_book_report_error			(EDataBook *book, const gchar *message);
+void		e_data_book_report_readonly			(EDataBook *book, gboolean readonly);
+void		e_data_book_report_online			(EDataBook *book, gboolean is_online);
+void		e_data_book_report_auth_required		(EDataBook *book, const ECredentials *credentials);
+void		e_data_book_report_opened			(EDataBook *book, const GError *error);
 
-void                    e_data_book_report_writable        (EDataBook                         *book,
-							    gboolean                           writable);
-void                    e_data_book_report_connection_status (EDataBook                        *book,
-							      gboolean                         is_online);
-
-void                    e_data_book_report_auth_required     (EDataBook                       *book);
-
-GType                   e_data_book_get_type               (void);
+gchar *		e_data_book_string_slist_to_comma_string	(const GSList *strings);
 
 G_END_DECLS
 
-#endif /* __E_DATA_BOOK_H__ */
+#endif /* E_DATA_BOOK_H */
