@@ -31,7 +31,7 @@
  * Currently simply strips a suffix introduced by a hyphen,
  * as in "America/Denver-(Standard)".
  */
-static const gchar *e_cal_match_location(const gchar *location)
+static const gchar *e_cal_match_location (const gchar *location)
 {
     icaltimezone *icomp;
     const gchar *tail;
@@ -40,22 +40,22 @@ static const gchar *e_cal_match_location(const gchar *location)
 
     icomp = icaltimezone_get_builtin_timezone (location);
     if (icomp) {
-        return icaltimezone_get_tzid(icomp);
+	return icaltimezone_get_tzid (icomp);
     }
 
     /* try a bit harder by stripping trailing suffix */
-    tail = strrchr(location, '-');
-    len = tail ? (tail - location) : strlen(location);
-    buffer = g_malloc(len + 1);
+    tail = strrchr (location, '-');
+    len = tail ? (tail - location) : strlen (location);
+    buffer = g_malloc (len + 1);
 
     if (buffer) {
-        memcpy(buffer, location, len);
-        buffer[len] = 0;
-        icomp = icaltimezone_get_builtin_timezone (buffer);
-        g_free(buffer);
-        if (icomp) {
-            return icaltimezone_get_tzid(icomp);
-        }
+	memcpy (buffer, location, len);
+	buffer[len] = 0;
+	icomp = icaltimezone_get_builtin_timezone (buffer);
+	g_free (buffer);
+	if (icomp) {
+	    return icaltimezone_get_tzid (icomp);
+	}
     }
 
     return NULL;
@@ -71,11 +71,11 @@ static const gchar *e_cal_match_location(const gchar *location)
  * Since: 2.24
  */
 const gchar *
-e_cal_match_tzid(const gchar *tzid)
+e_cal_match_tzid (const gchar *tzid)
 {
     const gchar *location;
     const gchar *systzid = NULL;
-    gsize len = strlen(tzid);
+    gsize len = strlen (tzid);
     gssize eostr;
 
     /*
@@ -87,22 +87,22 @@ e_cal_match_tzid(const gchar *tzid)
      */
     eostr = len - 1;
     while (eostr >= 0 &&
-           isdigit(tzid[eostr])) {
-        eostr--;
+	   isdigit (tzid[eostr])) {
+	eostr--;
     }
     while (eostr >= 0 &&
-           isspace(tzid[eostr])) {
-        eostr--;
+	   isspace (tzid[eostr])) {
+	eostr--;
     }
     if (eostr + 1 < len) {
-        gchar *strippedtzid = g_strndup(tzid, eostr + 1);
-        if (strippedtzid) {
-            systzid = e_cal_match_tzid(strippedtzid);
-            g_free(strippedtzid);
-            if (systzid) {
-                goto done;
-            }
-        }
+	gchar *strippedtzid = g_strndup (tzid, eostr + 1);
+	if (strippedtzid) {
+	    systzid = e_cal_match_tzid (strippedtzid);
+	    g_free (strippedtzid);
+	    if (systzid) {
+		goto done;
+	    }
+	}
     }
 
     /*
@@ -112,14 +112,14 @@ e_cal_match_tzid(const gchar *tzid)
      * is a known location; start with the whole string (just in case)
      */
     for (location = tzid;
-         location && location[0];
-         location = strchr(location + 1, '/')) {
-        systzid = e_cal_match_location(location[0] == '/' ?
-                                       location + 1 :
-                                       location);
-        if (systzid) {
-            goto done;
-        }
+	 location && location[0];
+	 location = strchr (location + 1, '/')) {
+	systzid = e_cal_match_location (location[0] == '/' ?
+				       location + 1 :
+				       location);
+	if (systzid) {
+	    goto done;
+	}
     }
 
     /* TODO: lookup table for Exchange TZIDs */
@@ -136,52 +136,52 @@ e_cal_match_tzid(const gchar *tzid)
          *
          * So better avoid matching against it...
          */
-        return NULL;
+	return NULL;
     } else {
-        return systzid;
+	return systzid;
     }
 }
 
-static void patch_tzids(icalcomponent *subcomp,
+static void patch_tzids (icalcomponent *subcomp,
                         GHashTable *mapping)
 {
     gchar *tzid = NULL;
 
-    if (icalcomponent_isa(subcomp) != ICAL_VTIMEZONE_COMPONENT) {
-        icalproperty *prop = icalcomponent_get_first_property(subcomp,
-                                                              ICAL_ANY_PROPERTY);
-        while (prop) {
-            icalparameter *param = icalproperty_get_first_parameter(prop,
-                                                                    ICAL_TZID_PARAMETER);
-            while (param) {
-                const gchar *oldtzid;
-                const gchar *newtzid;
+    if (icalcomponent_isa (subcomp) != ICAL_VTIMEZONE_COMPONENT) {
+	icalproperty *prop = icalcomponent_get_first_property (subcomp,
+							      ICAL_ANY_PROPERTY);
+	while (prop) {
+	    icalparameter *param = icalproperty_get_first_parameter (prop,
+								    ICAL_TZID_PARAMETER);
+	    while (param) {
+		const gchar *oldtzid;
+		const gchar *newtzid;
 
-                g_free(tzid);
-                tzid = g_strdup(icalparameter_get_tzid(param));
+		g_free (tzid);
+		tzid = g_strdup (icalparameter_get_tzid (param));
 
-                if (!g_hash_table_lookup_extended(mapping,
-                                                  tzid,
-                                                  (gpointer *)&oldtzid,
-                                                  (gpointer *)&newtzid)) {
+		if (!g_hash_table_lookup_extended (mapping,
+						  tzid,
+						  (gpointer *)&oldtzid,
+						  (gpointer *)&newtzid)) {
                     /* Corresponding VTIMEZONE not seen before! */
-                    newtzid = e_cal_match_tzid(tzid);
-                }
-                if (newtzid) {
-                    icalparameter_set_tzid(param, newtzid);
-                }
-                param = icalproperty_get_next_parameter(prop,
-                                                        ICAL_TZID_PARAMETER);
-            }
-            prop = icalcomponent_get_next_property(subcomp,
-                                                   ICAL_ANY_PROPERTY);
-        }
+		    newtzid = e_cal_match_tzid (tzid);
+		}
+		if (newtzid) {
+		    icalparameter_set_tzid (param, newtzid);
+		}
+		param = icalproperty_get_next_parameter (prop,
+							ICAL_TZID_PARAMETER);
+	    }
+	    prop = icalcomponent_get_next_property (subcomp,
+						   ICAL_ANY_PROPERTY);
+	}
     }
 
-    g_free(tzid);
+    g_free (tzid);
 }
 
-static void addsystemtz(gpointer key,
+static void addsystemtz (gpointer key,
                         gpointer value,
                         gpointer user_data)
 {
@@ -189,10 +189,10 @@ static void addsystemtz(gpointer key,
     icalcomponent *comp = user_data;
     icaltimezone *zone;
 
-    zone = icaltimezone_get_builtin_timezone_from_tzid(tzid);
+    zone = icaltimezone_get_builtin_timezone_from_tzid (tzid);
     if (zone) {
-        icalcomponent_add_component(comp,
-                                    icalcomponent_new_clone(icaltimezone_get_component(zone)));
+	icalcomponent_add_component (comp,
+				    icalcomponent_new_clone (icaltimezone_get_component (zone)));
     }
 }
 
@@ -261,7 +261,7 @@ e_cal_check_timezones (icalcomponent *comp,
 {
     gboolean success = TRUE;
     icalcomponent *subcomp = NULL;
-    icaltimezone *zone = icaltimezone_new();
+    icaltimezone *zone = icaltimezone_new ();
     gchar *key = NULL, *value = NULL;
     gchar *buffer = NULL;
     gchar *zonestr = NULL;
@@ -269,88 +269,88 @@ e_cal_check_timezones (icalcomponent *comp,
     GList *l;
 
     /** a hash from old to new tzid; strings dynamically allocated */
-    GHashTable *mapping = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
+    GHashTable *mapping = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 
     /** a hash of all system time zone IDs which have to be added; strings are shared with mapping hash */
-    GHashTable *systemtzids = g_hash_table_new(g_str_hash, g_str_equal);
+    GHashTable *systemtzids = g_hash_table_new (g_str_hash, g_str_equal);
 
     *error = NULL;
 
     if (!mapping || !zone) {
-        goto nomem;
+	goto nomem;
     }
 
     /* iterate over all VTIMEZONE definitions */
-    subcomp = icalcomponent_get_first_component(comp,
-                                                ICAL_VTIMEZONE_COMPONENT);
+    subcomp = icalcomponent_get_first_component (comp,
+						ICAL_VTIMEZONE_COMPONENT);
     while (subcomp) {
-        if (icaltimezone_set_component(zone, subcomp)) {
-            g_free(tzid);
-            tzid = g_strdup(icaltimezone_get_tzid(zone));
-            if (tzid) {
-                const gchar *newtzid = e_cal_match_tzid(tzid);
-                if (newtzid) {
+	if (icaltimezone_set_component (zone, subcomp)) {
+	    g_free (tzid);
+	    tzid = g_strdup (icaltimezone_get_tzid (zone));
+	    if (tzid) {
+		const gchar *newtzid = e_cal_match_tzid (tzid);
+		if (newtzid) {
                     /* matched against system time zone */
-                    g_free(key);
-                    key = g_strdup(tzid);
-                    if (!key) {
-                        goto nomem;
-                    }
+		    g_free (key);
+		    key = g_strdup (tzid);
+		    if (!key) {
+			goto nomem;
+		    }
 
-                    g_free(value);
-                    value = g_strdup(newtzid);
-                    if (!value) {
-                        goto nomem;
-                    }
+		    g_free (value);
+		    value = g_strdup (newtzid);
+		    if (!value) {
+			goto nomem;
+		    }
 
-                    g_hash_table_insert(mapping, key, value);
-                    g_hash_table_insert(systemtzids, value, NULL);
-                    key =
-                        value = NULL;
-                } else {
-                    gint counter;
+		    g_hash_table_insert (mapping, key, value);
+		    g_hash_table_insert (systemtzids, value, NULL);
+		    key =
+			value = NULL;
+		} else {
+		    gint counter;
 
-                    zonestr = icalcomponent_as_ical_string_r(subcomp);
+		    zonestr = icalcomponent_as_ical_string_r (subcomp);
 
                     /* check for collisions with existing timezones */
-                    for (counter = 0;
-                         counter < 100 /* sanity limit */;
-                         counter++) {
-                        icaltimezone *existing_zone;
+		    for (counter = 0;
+			 counter < 100 /* sanity limit */;
+			 counter++) {
+			icaltimezone *existing_zone;
 
-                        if (counter) {
-                            g_free(value);
+			if (counter) {
+			    g_free (value);
                             value = g_strdup_printf("%s %d", tzid, counter);
-                        }
-                        existing_zone = tzlookup(counter ? value : tzid,
-                                                 custom,
-                                                 error);
-                        if (!existing_zone) {
-                            if (*error) {
-                                goto failed;
-                            } else {
-                                break;
-                            }
-                        }
-                        g_free(buffer);
-                        buffer = icalcomponent_as_ical_string_r(icaltimezone_get_component(existing_zone));
+			}
+			existing_zone = tzlookup (counter ? value : tzid,
+						 custom,
+						 error);
+			if (!existing_zone) {
+			    if (*error) {
+				goto failed;
+			    } else {
+				break;
+			    }
+			}
+			g_free (buffer);
+			buffer = icalcomponent_as_ical_string_r (icaltimezone_get_component (existing_zone));
 
-                        if (counter) {
+			if (counter) {
                             gchar *fulltzid = g_strdup_printf("TZID:%s", value);
                             gsize baselen = strlen("TZID:") + strlen(tzid);
-                            gsize fulllen = strlen(fulltzid);
-                            gchar *tzidprop;
+			    gsize fulllen = strlen (fulltzid);
+			    gchar *tzidprop;
                             /*
                              * Map TZID with counter suffix back to basename.
                              */
-                            tzidprop = strstr(buffer, fulltzid);
-                            if (tzidprop) {
-                                memmove(tzidprop + baselen,
-                                        tzidprop + fulllen,
-                                        strlen(tzidprop + fulllen) + 1);
-                            }
-                            g_free(fulltzid);
-                        }
+			    tzidprop = strstr (buffer, fulltzid);
+			    if (tzidprop) {
+				memmove (tzidprop + baselen,
+					tzidprop + fulllen,
+					strlen (tzidprop + fulllen) + 1);
+			    }
+			    g_free (fulltzid);
+			}
 
                         /*
                          * If the strings are identical, then the
@@ -362,41 +362,41 @@ e_cal_check_timezones (icalcomponent *comp,
                          * is expected to occur rarely (if at all) in
                          * practice.
                          */
-                        if (!strcmp(zonestr, buffer)) {
-                            break;
-                        }
-                    }
+			if (!strcmp (zonestr, buffer)) {
+			    break;
+			}
+		    }
 
-                    if (!counter) {
+		    if (!counter) {
                         /* does not exist, nothing to do */
-                    } else {
+		    } else {
                         /* timezone renamed */
-                        icalproperty *prop = icalcomponent_get_first_property(subcomp,
-                                                                              ICAL_TZID_PROPERTY);
-                        while (prop) {
+			icalproperty *prop = icalcomponent_get_first_property (subcomp,
+									      ICAL_TZID_PROPERTY);
+			while (prop) {
                             icalproperty_set_value_from_string(prop, value, "NO");
-                            prop = icalcomponent_get_next_property(subcomp,
-                                                                   ICAL_ANY_PROPERTY);
-                        }
-                        g_free(key);
-                        key = g_strdup(tzid);
-                        g_hash_table_insert(mapping, key, value);
-                        key =
-                            value = NULL;
-                    }
-                }
-            }
-        }
+			    prop = icalcomponent_get_next_property (subcomp,
+								   ICAL_ANY_PROPERTY);
+			}
+			g_free (key);
+			key = g_strdup (tzid);
+			g_hash_table_insert (mapping, key, value);
+			key =
+			    value = NULL;
+		    }
+		}
+	    }
+	}
 
-        subcomp = icalcomponent_get_next_component(comp,
-                                                   ICAL_VTIMEZONE_COMPONENT);
+	subcomp = icalcomponent_get_next_component (comp,
+						   ICAL_VTIMEZONE_COMPONENT);
     }
 
     /*
      * now replace all TZID parameters in place
      */
-    subcomp = icalcomponent_get_first_component(comp,
-                                                ICAL_ANY_COMPONENT);
+    subcomp = icalcomponent_get_first_component (comp,
+						ICAL_ANY_COMPONENT);
     while (subcomp) {
         /*
          * Leave VTIMEZONE unchanged, iterate over properties of
@@ -407,20 +407,20 @@ e_cal_check_timezones (icalcomponent *comp,
          * little additional gain. However, newly used time zones are
          * added below.
          */
-        patch_tzids (subcomp, mapping);
-        subcomp = icalcomponent_get_next_component(comp,
-                                                   ICAL_ANY_COMPONENT);
+	patch_tzids (subcomp, mapping);
+	subcomp = icalcomponent_get_next_component (comp,
+						   ICAL_ANY_COMPONENT);
     }
 
     for (l = comps; l; l = l->next) {
-        patch_tzids (l->data, mapping);
+	patch_tzids (l->data, mapping);
     }
 
     /*
      * add system time zones that we mapped to: adding them ensures
      * that the VCALENDAR remains consistent
      */
-    g_hash_table_foreach(systemtzids, addsystemtz, comp);
+    g_hash_table_foreach (systemtzids, addsystemtz, comp);
 
     goto done;
  nomem:
@@ -434,19 +434,19 @@ e_cal_check_timezones (icalcomponent *comp,
     success = FALSE;
  done:
     if (mapping) {
-        g_hash_table_destroy(mapping);
+	g_hash_table_destroy (mapping);
     }
     if (systemtzids) {
-        g_hash_table_destroy(systemtzids);
+	g_hash_table_destroy (systemtzids);
     }
     if (zone) {
-        icaltimezone_free(zone, 1);
+	icaltimezone_free (zone, 1);
     }
-    g_free(tzid);
-    g_free(zonestr);
-    g_free(buffer);
-    g_free(key);
-    g_free(value);
+    g_free (tzid);
+    g_free (zonestr);
+    g_free (buffer);
+    g_free (key);
+    g_free (value);
 
     return success;
 }
@@ -456,7 +456,7 @@ e_cal_check_timezones (icalcomponent *comp,
  * @custom: must be a valid ECal pointer
  *
  * An implementation of the tzlookup callback which clients
- * can use. Calls #e_cal_get_timezone.
+ * can use. Calls e_cal_get_timezone().
  *
  * Since: 2.24
  */
@@ -465,24 +465,25 @@ e_cal_tzlookup_ecal (const gchar *tzid,
                      gconstpointer custom,
                      GError **error)
 {
-    ECal *ecal = (ECal *)custom;
-    icaltimezone *zone = NULL;
+	ECal *ecal = (ECal *) custom;
+	icaltimezone *zone = NULL;
+	GError *local_error = NULL;
 
-    if (e_cal_get_timezone(ecal, tzid, &zone, error)) {
-        g_assert(*error == NULL);
-        return zone;
-    } else {
-        g_assert(*error);
-        if ((*error)->domain == E_CALENDAR_ERROR &&
-            (*error)->code == E_CALENDAR_STATUS_OBJECT_NOT_FOUND) {
-            /*
-             * we had to trigger this error to check for the timezone existance,
-             * clear it and return NULL
-             */
-            g_clear_error(error);
-        }
-        return NULL;
-    }
+	if (e_cal_get_timezone (ecal, tzid, &zone, &local_error)) {
+		g_warn_if_fail (local_error == NULL);
+		return zone;
+	}
+
+	if (g_error_matches (local_error, E_CALENDAR_ERROR,
+		E_CALENDAR_STATUS_OBJECT_NOT_FOUND)) {
+		/* We had to trigger this error to check for the
+		 * timezone existance, clear it and return NULL. */
+		g_clear_error (&local_error);
+	}
+
+	g_propagate_error (error, local_error);
+
+	return NULL;
 }
 
 /**
@@ -502,7 +503,7 @@ e_cal_tzlookup_icomp (const gchar *tzid,
                       gconstpointer custom,
                       GError **error)
 {
-    icalcomponent *icomp = (icalcomponent *)custom;
+    icalcomponent *icomp = (icalcomponent *) custom;
 
-    return icalcomponent_get_timezone(icomp, (gchar *)tzid);
+    return icalcomponent_get_timezone (icomp, (gchar *) tzid);
 }
