@@ -34,10 +34,6 @@
 
 #include "camel-stream-mem.h"
 
-#define CAMEL_STREAM_MEM_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), CAMEL_TYPE_STREAM_MEM, CamelStreamMemPrivate))
-
 struct _CamelStreamMemPrivate {
 	guint owner  : 1;	/* do we own the buffer? */
 	guint secure : 1;	/* do we clear the buffer on finalize?
@@ -77,7 +73,7 @@ stream_mem_finalize (GObject *object)
 {
 	CamelStreamMemPrivate *priv;
 
-	priv = CAMEL_STREAM_MEM_GET_PRIVATE (object);
+	priv = CAMEL_STREAM_MEM (object)->priv;
 
 	if (priv->buffer && priv->owner) {
 		/* TODO: we need our own bytearray type since we don't know
@@ -101,7 +97,7 @@ stream_mem_read (CamelStream *stream,
 	CamelStreamMemPrivate *priv;
 	gssize nread;
 
-	priv = CAMEL_STREAM_MEM_GET_PRIVATE (stream);
+	priv = CAMEL_STREAM_MEM (stream)->priv;
 
 	nread = MIN (n, priv->buffer->len - priv->position);
 	if (nread > 0) {
@@ -123,11 +119,11 @@ stream_mem_write (CamelStream *stream,
 	CamelStreamMemPrivate *priv;
 	gssize nwrite = n;
 
-	priv = CAMEL_STREAM_MEM_GET_PRIVATE (stream);
+	priv = CAMEL_STREAM_MEM (stream)->priv;
 
 	/* FIXME: we shouldn't use g_byte_arrays or g_malloc perhaps? */
 	if (priv->position == priv->buffer->len) {
-		g_byte_array_append (priv->buffer, (const guint8 *)buffer, nwrite);
+		g_byte_array_append (priv->buffer, (const guint8 *) buffer, nwrite);
 	} else {
 		g_byte_array_set_size (priv->buffer, nwrite + priv->buffer->len);
 		memcpy (priv->buffer->data + priv->position, buffer, nwrite);
@@ -142,7 +138,7 @@ stream_mem_eos (CamelStream *stream)
 {
 	CamelStreamMemPrivate *priv;
 
-	priv = CAMEL_STREAM_MEM_GET_PRIVATE (stream);
+	priv = CAMEL_STREAM_MEM (stream)->priv;
 
 	return priv->buffer->len <= priv->position;
 }
@@ -152,7 +148,7 @@ stream_mem_tell (GSeekable *seekable)
 {
 	CamelStreamMemPrivate *priv;
 
-	priv = CAMEL_STREAM_MEM_GET_PRIVATE (seekable);
+	priv = CAMEL_STREAM_MEM (seekable)->priv;
 
 	return priv->position;
 }
@@ -173,7 +169,7 @@ stream_mem_seek (GSeekable *seekable,
 	CamelStreamMemPrivate *priv;
 	goffset position;
 
-	priv = CAMEL_STREAM_MEM_GET_PRIVATE (seekable);
+	priv = CAMEL_STREAM_MEM (seekable)->priv;
 
 	switch (type) {
 	case G_SEEK_SET:
@@ -254,7 +250,8 @@ camel_stream_mem_seekable_init (GSeekableIface *interface)
 static void
 camel_stream_mem_init (CamelStreamMem *stream)
 {
-	stream->priv = CAMEL_STREAM_MEM_GET_PRIVATE (stream);
+	stream->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		stream, CAMEL_TYPE_STREAM_MEM, CamelStreamMemPrivate);
 }
 
 /**
@@ -292,7 +289,7 @@ camel_stream_mem_new_with_buffer (const gchar *buffer,
 	g_return_val_if_fail (buffer != NULL, NULL);
 
 	ba = g_byte_array_new ();
-	g_byte_array_append (ba, (const guint8 *)buffer, len);
+	g_byte_array_append (ba, (const guint8 *) buffer, len);
 
 	return camel_stream_mem_new_with_byte_array (ba);
 }
@@ -317,7 +314,7 @@ camel_stream_mem_new_with_byte_array (GByteArray *buffer)
 	g_return_val_if_fail (buffer != NULL, NULL);
 
 	stream = g_object_new (CAMEL_TYPE_STREAM_MEM, NULL);
-	priv = CAMEL_STREAM_MEM_GET_PRIVATE (stream);
+	priv = CAMEL_STREAM_MEM (stream)->priv;
 
 	priv->buffer = buffer;
 	priv->owner = TRUE;
@@ -407,7 +404,7 @@ camel_stream_mem_set_buffer (CamelStreamMem *mem,
 	g_return_if_fail (buffer != NULL);
 
 	ba = g_byte_array_new ();
-	g_byte_array_append (ba, (const guint8 *)buffer, len);
+	g_byte_array_append (ba, (const guint8 *) buffer, len);
 	camel_stream_mem_set_byte_array (mem, ba);
 	mem->priv->owner = TRUE;
 }
