@@ -31,10 +31,6 @@
 #include "camel-imap-folder.h"
 #include "camel-imap-wrapper.h"
 
-#define CAMEL_IMAP_WRAPPER_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), CAMEL_TYPE_IMAP_WRAPPER, CamelImapWrapperPrivate))
-
 struct _CamelImapWrapperPrivate {
 	GMutex *lock;
 };
@@ -90,9 +86,10 @@ imap_wrapper_finalize (GObject *object)
 }
 
 static gssize
-imap_wrapper_write_to_stream (CamelDataWrapper *data_wrapper,
-                              CamelStream *stream,
-                              GError **error)
+imap_wrapper_write_to_stream_sync (CamelDataWrapper *data_wrapper,
+                                   CamelStream *stream,
+                                   GCancellable *cancellable,
+                                   GError **error)
 {
 	CamelImapWrapper *imap_wrapper = CAMEL_IMAP_WRAPPER (data_wrapper);
 
@@ -102,7 +99,7 @@ imap_wrapper_write_to_stream (CamelDataWrapper *data_wrapper,
 
 		datastream = camel_imap_folder_fetch_data (
 			imap_wrapper->folder, imap_wrapper->uid,
-			imap_wrapper->part_spec, FALSE, NULL);
+			imap_wrapper->part_spec, FALSE, cancellable, NULL);
 
 		if (!datastream) {
 			CAMEL_IMAP_WRAPPER_UNLOCK (imap_wrapper, lock);
@@ -125,7 +122,7 @@ imap_wrapper_write_to_stream (CamelDataWrapper *data_wrapper,
 	CAMEL_IMAP_WRAPPER_UNLOCK (imap_wrapper, lock);
 
 	return CAMEL_DATA_WRAPPER_CLASS (camel_imap_wrapper_parent_class)->
-		write_to_stream (data_wrapper, stream, error);
+		write_to_stream_sync (data_wrapper, stream, cancellable, error);
 }
 
 static void
@@ -141,13 +138,15 @@ camel_imap_wrapper_class_init (CamelImapWrapperClass *class)
 	object_class->finalize = imap_wrapper_finalize;
 
 	data_wrapper_class = CAMEL_DATA_WRAPPER_CLASS (class);
-	data_wrapper_class->write_to_stream = imap_wrapper_write_to_stream;
+	data_wrapper_class->write_to_stream_sync = imap_wrapper_write_to_stream_sync;
 }
 
 static void
 camel_imap_wrapper_init (CamelImapWrapper *imap_wrapper)
 {
-	imap_wrapper->priv = CAMEL_IMAP_WRAPPER_GET_PRIVATE (imap_wrapper);
+	imap_wrapper->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		imap_wrapper, CAMEL_TYPE_IMAP_WRAPPER,
+		CamelImapWrapperPrivate);
 	imap_wrapper->priv->lock = g_mutex_new ();
 }
 
@@ -160,17 +159,20 @@ camel_imap_wrapper_new (CamelImapFolder *imap_folder,
 	CamelImapWrapper *imap_wrapper;
 	CamelStore *store;
 	CamelStream *stream;
+	CamelURL *url;
 	gboolean sync_offline = FALSE;
 
 	store = camel_folder_get_parent_store (CAMEL_FOLDER (imap_folder));
+	url = camel_service_get_camel_url (CAMEL_SERVICE (store));
 	sync_offline =
-		camel_url_get_param (((CamelService *) store)->url, "sync_offline") != NULL ||
-		camel_offline_folder_get_offline_sync (CAMEL_OFFLINE_FOLDER (imap_folder));
+		camel_url_get_param (url, "sync_offline") != NULL ||
+		camel_offline_folder_get_offline_sync (
+			CAMEL_OFFLINE_FOLDER (imap_folder));
 
 	imap_wrapper = g_object_new (CAMEL_TYPE_IMAP_WRAPPER, NULL);
 	camel_data_wrapper_set_mime_type_field (CAMEL_DATA_WRAPPER (imap_wrapper), type);
-	((CamelDataWrapper *)imap_wrapper)->offline = !sync_offline;
-	((CamelDataWrapper *)imap_wrapper)->encoding = encoding;
+	((CamelDataWrapper *) imap_wrapper)->offline = !sync_offline;
+	((CamelDataWrapper *) imap_wrapper)->encoding = encoding;
 
 	imap_wrapper->folder = g_object_ref (imap_folder);
 	imap_wrapper->uid = g_strdup (uid);
@@ -181,12 +183,12 @@ camel_imap_wrapper_new (CamelImapFolder *imap_folder,
 
 	/* Download the attachments if sync_offline is set, else skip them by checking only in cache */
 	stream = camel_imap_folder_fetch_data (imap_folder, uid, part_spec,
-			!sync_offline, NULL);
+			!sync_offline, NULL, NULL);
 
 	if (stream) {
 		imap_wrapper_hydrate (imap_wrapper, stream);
 		g_object_unref (stream);
 	}
 
-	return (CamelDataWrapper *)imap_wrapper;
+	return (CamelDataWrapper *) imap_wrapper;
 }
