@@ -44,11 +44,11 @@
 
 #define CAMEL_SPOOL_SUMMARY_VERSION (0x400)
 
-static gint spool_summary_load(CamelLocalSummary *cls, gint forceindex, GError **error);
-static gint spool_summary_check(CamelLocalSummary *cls, CamelFolderChangeInfo *changeinfo, GError **error);
+static gint spool_summary_load (CamelLocalSummary *cls, gint forceindex, GError **error);
+static gint spool_summary_check (CamelLocalSummary *cls, CamelFolderChangeInfo *changeinfo, GCancellable *cancellable, GError **error);
 
-static gint spool_summary_sync_full(CamelMboxSummary *cls, gboolean expunge, CamelFolderChangeInfo *changeinfo, GError **error);
-static gint spool_summary_need_index(void);
+static gint spool_summary_sync_full (CamelMboxSummary *cls, gboolean expunge, CamelFolderChangeInfo *changeinfo, GCancellable *cancellable, GError **error);
+static gint spool_summary_need_index (void);
 
 G_DEFINE_TYPE (CamelSpoolSummary, camel_spool_summary, CAMEL_TYPE_MBOX_SUMMARY)
 
@@ -68,7 +68,7 @@ camel_spool_summary_class_init (CamelSpoolSummaryClass *class)
 }
 
 static void
-camel_spool_summary_init(CamelSpoolSummary *spool_summary)
+camel_spool_summary_init (CamelSpoolSummary *spool_summary)
 {
 	CamelFolderSummary *folder_summary;
 
@@ -87,7 +87,7 @@ camel_spool_summary_new (CamelFolder *folder,
 	CamelSpoolSummary *new;
 
 	new = g_object_new (CAMEL_TYPE_SPOOL_SUMMARY, NULL);
-	((CamelFolderSummary *)new)->folder = folder;
+	((CamelFolderSummary *) new)->folder = folder;
 	if (folder) {
 		CamelStore *parent_store;
 
@@ -96,8 +96,8 @@ camel_spool_summary_new (CamelFolder *folder,
 		((CamelFolderSummary *)new)->sort_by = "bdata";
 		((CamelFolderSummary *)new)->collate = "spool_frompos_sort";
 	}
-	camel_local_summary_construct((CamelLocalSummary *)new, NULL, mbox_name, NULL);
-	camel_folder_summary_load_from_db ((CamelFolderSummary *)new, NULL);
+	camel_local_summary_construct ((CamelLocalSummary *) new, NULL, mbox_name, NULL);
+	camel_folder_summary_load_from_db ((CamelFolderSummary *) new, NULL);
 	return new;
 }
 
@@ -115,6 +115,7 @@ static gint
 spool_summary_sync_full (CamelMboxSummary *cls,
                          gboolean expunge,
                          CamelFolderChangeInfo *changeinfo,
+                         GCancellable *cancellable,
                          GError **error)
 {
 	gint fd = -1, fdout = -1;
@@ -127,17 +128,17 @@ spool_summary_sync_full (CamelMboxSummary *cls,
 
 	d(printf("performing full summary/sync\n"));
 
-	camel_operation_start(NULL, _("Storing folder"));
+	camel_operation_push_message (cancellable, _("Storing folder"));
 
-	fd = open(((CamelLocalSummary *)cls)->folder_path, O_RDWR|O_LARGEFILE);
+	fd = open (((CamelLocalSummary *) cls)->folder_path, O_RDWR|O_LARGEFILE);
 	if (fd == -1) {
 		g_set_error (
 			error, G_IO_ERROR,
 			g_io_error_from_errno (errno),
 			_("Could not open file: %s: %s"),
-			((CamelLocalSummary *)cls)->folder_path,
+			((CamelLocalSummary *) cls)->folder_path,
 			g_strerror (errno));
-		camel_operation_end(NULL);
+		camel_operation_pop_message (cancellable);
 		return -1;
 	}
 
@@ -154,41 +155,43 @@ spool_summary_sync_full (CamelMboxSummary *cls,
 		goto error;
 	}
 
-	if (camel_mbox_summary_sync_mbox((CamelMboxSummary *)cls, flags, changeinfo, fd, fdout, error) == -1)
+	if (camel_mbox_summary_sync_mbox (
+		(CamelMboxSummary *) cls, flags, changeinfo,
+		fd, fdout, cancellable, error) == -1)
 		goto error;
 
 	/* sync out content */
-	if (fsync(fdout) == -1) {
+	if (fsync (fdout) == -1) {
 		g_warning("Cannot synchronize temporary folder: %s", g_strerror (errno));
 		g_set_error (
 			error, G_IO_ERROR,
 			g_io_error_from_errno (errno),
 			_("Could not synchronize temporary folder %s: %s"),
-			((CamelLocalSummary *)cls)->folder_path,
+			((CamelLocalSummary *) cls)->folder_path,
 			g_strerror (errno));
 		goto error;
 	}
 
 	/* see if we can write this much to the spool file */
-	if (fstat(fd, &st) == -1) {
+	if (fstat (fd, &st) == -1) {
 		g_warning("Cannot synchronize temporary folder: %s", g_strerror (errno));
 		g_set_error (
 			error, G_IO_ERROR,
 			g_io_error_from_errno (errno),
 			_("Could not synchronize temporary folder %s: %s"),
-			((CamelLocalSummary *)cls)->folder_path,
+			((CamelLocalSummary *) cls)->folder_path,
 			g_strerror (errno));
 		goto error;
 	}
 	spoollen = st.st_size;
 
-	if (fstat(fdout, &st) == -1) {
+	if (fstat (fdout, &st) == -1) {
 		g_warning("Cannot synchronize temporary folder: %s", g_strerror (errno));
 		g_set_error (
 			error, G_IO_ERROR,
 			g_io_error_from_errno (errno),
 			_("Could not synchronize temporary folder %s: %s"),
-			((CamelLocalSummary *)cls)->folder_path,
+			((CamelLocalSummary *) cls)->folder_path,
 			g_strerror (errno));
 		goto error;
 	}
@@ -196,35 +199,35 @@ spool_summary_sync_full (CamelMboxSummary *cls,
 
 	/* I think this is the right way to do this - checking that the file will fit the new data */
 	if (outlen>0
-	    && (lseek(fd, outlen-1, SEEK_SET) == -1
+	    && (lseek (fd, outlen-1, SEEK_SET) == -1
 		|| write(fd, "", 1) != 1
-		|| fsync(fd) == -1
-		|| lseek(fd, 0, SEEK_SET) == -1
-		|| lseek(fdout, 0, SEEK_SET) == -1)) {
+		|| fsync (fd) == -1
+		|| lseek (fd, 0, SEEK_SET) == -1
+		|| lseek (fdout, 0, SEEK_SET) == -1)) {
 		g_warning("Cannot synchronize spool folder: %s", g_strerror (errno));
 		g_set_error (
 			error, G_IO_ERROR,
 			g_io_error_from_errno (errno),
 			_("Could not synchronize spool folder %s: %s"),
-			((CamelLocalSummary *)cls)->folder_path,
+			((CamelLocalSummary *) cls)->folder_path,
 			g_strerror (errno));
 		/* incase we ran out of room, remove any trailing space first */
-		ftruncate(fd, spoollen);
+		ftruncate (fd, spoollen);
 		goto error;
 	}
 
 	/* now copy content back */
-	buffer = g_malloc(8192);
+	buffer = g_malloc (8192);
 	size = 1;
 	while (size>0) {
 		do {
-			size = read(fdout, buffer, 8192);
+			size = read (fdout, buffer, 8192);
 		} while (size == -1 && errno == EINTR);
 
 		if (size > 0) {
 			p = buffer;
 			do {
-				sizeout = write(fd, p, size);
+				sizeout = write (fd, p, size);
 				if (sizeout > 0) {
 					p+= sizeout;
 					size -= sizeout;
@@ -239,64 +242,64 @@ spool_summary_sync_full (CamelMboxSummary *cls,
 				g_io_error_from_errno (errno),
 				_("Could not synchronize spool folder %s: %s\n"
 				  "Folder may be corrupt, copy saved in '%s'"),
-				((CamelLocalSummary *)cls)->folder_path,
+				((CamelLocalSummary *) cls)->folder_path,
 				g_strerror (errno), tmpname);
 			/* so we dont delete it */
 			tmpname[0] = '\0';
-			g_free(buffer);
+			g_free (buffer);
 			goto error;
 		}
 	}
 
-	g_free(buffer);
+	g_free (buffer);
 
 	d(printf("Closing folders\n"));
 
-	if (ftruncate(fd, outlen) == -1) {
+	if (ftruncate (fd, outlen) == -1) {
 		g_set_error (
 			error, G_IO_ERROR,
 			g_io_error_from_errno (errno),
 			_("Could not synchronize spool folder %s: %s\n"
 			  "Folder may be corrupt, copy saved in '%s'"),
-			((CamelLocalSummary *)cls)->folder_path,
+			((CamelLocalSummary *) cls)->folder_path,
 			g_strerror (errno), tmpname);
 		tmpname[0] = '\0';
 		goto error;
 	}
 
-	if (close(fd) == -1) {
+	if (close (fd) == -1) {
 		g_warning("Cannot close source folder: %s", g_strerror (errno));
 		g_set_error (
 			error, G_IO_ERROR,
 			g_io_error_from_errno (errno),
 			_("Could not synchronize spool folder %s: %s\n"
 			  "Folder may be corrupt, copy saved in '%s'"),
-			((CamelLocalSummary *)cls)->folder_path,
+			((CamelLocalSummary *) cls)->folder_path,
 			g_strerror (errno), tmpname);
 		tmpname[0] = '\0';
 		fd = -1;
 		goto error;
 	}
 
-	close(fdout);
+	close (fdout);
 
 	if (tmpname[0] != '\0')
-		unlink(tmpname);
+		unlink (tmpname);
 
-	camel_operation_end(NULL);
+	camel_operation_pop_message (cancellable);
 
 	return 0;
  error:
 	if (fd != -1)
-		close(fd);
+		close (fd);
 
 	if (fdout != -1)
-		close(fdout);
+		close (fdout);
 
 	if (tmpname[0] != '\0')
-		unlink(tmpname);
+		unlink (tmpname);
 
-	camel_operation_end(NULL);
+	camel_operation_pop_message (cancellable);
 
 	return -1;
 }
@@ -304,33 +307,36 @@ spool_summary_sync_full (CamelMboxSummary *cls,
 static gint
 spool_summary_check (CamelLocalSummary *cls,
                      CamelFolderChangeInfo *changeinfo,
+                     GCancellable *cancellable,
                      GError **error)
 {
 	gint i, work, count;
 	struct stat st;
-	CamelFolderSummary *s = (CamelFolderSummary *)cls;
+	CamelFolderSummary *s = (CamelFolderSummary *) cls;
 
-	if (CAMEL_LOCAL_SUMMARY_CLASS (camel_spool_summary_parent_class)->check(cls, changeinfo, error) == -1)
+	if (CAMEL_LOCAL_SUMMARY_CLASS (camel_spool_summary_parent_class)->check (cls, changeinfo, cancellable, error) == -1)
 		return -1;
 
 	/* check to see if we need to copy/update the file; missing xev headers prompt this */
 	work = FALSE;
 	camel_folder_summary_prepare_fetch_all (s, error);
-	count = camel_folder_summary_count(s);
+	count = camel_folder_summary_count (s);
 	for (i=0;!work && i<count; i++) {
-		CamelMboxMessageInfo *info = (CamelMboxMessageInfo *)camel_folder_summary_index(s, i);
-		g_assert(info);
+		CamelMboxMessageInfo *info = (CamelMboxMessageInfo *) camel_folder_summary_index (s, i);
+		g_assert (info);
 		work = (info->info.info.flags & (CAMEL_MESSAGE_FOLDER_NOXEV)) != 0;
-		camel_message_info_free((CamelMessageInfo *)info);
+		camel_message_info_free ((CamelMessageInfo *) info);
 	}
 
 	/* if we do, then write out the headers using sync_full, etc */
 	if (work) {
 		d(printf("Have to add new headers, re-syncing from the start to accomplish this\n"));
-		if (CAMEL_MBOX_SUMMARY_GET_CLASS (cls)->sync_full (CAMEL_MBOX_SUMMARY (cls), FALSE, changeinfo, error) == -1)
+		if (CAMEL_MBOX_SUMMARY_GET_CLASS (cls)->sync_full (
+			CAMEL_MBOX_SUMMARY (cls), FALSE,
+			changeinfo, cancellable, error) == -1)
 			return -1;
 
-		if (g_stat(cls->folder_path, &st) == -1) {
+		if (g_stat (cls->folder_path, &st) == -1) {
 			g_set_error (
 				error, G_IO_ERROR,
 				g_io_error_from_errno (errno),
@@ -339,14 +345,14 @@ spool_summary_check (CamelLocalSummary *cls,
 			return -1;
 		}
 
-		((CamelMboxSummary *)cls)->folder_size = st.st_size;
-		((CamelFolderSummary *)cls)->time = st.st_mtime;
+		((CamelMboxSummary *) cls)->folder_size = st.st_size;
+		((CamelFolderSummary *) cls)->time = st.st_mtime;
 	}
 
 	return 0;
 }
 
 static gint
-spool_summary_need_index(void) {
+spool_summary_need_index (void) {
 	return 0;
 }
