@@ -54,20 +54,33 @@
 
 #define DUMP_EXTENSIONS
 
-G_DEFINE_TYPE (CamelNNTPStore, camel_nntp_store, CAMEL_TYPE_DISCO_STORE)
+static GInitableIface *parent_initable_interface;
+
+/* Forward Declarations */
+static void camel_nntp_store_initable_init (GInitableIface *interface);
+
+G_DEFINE_TYPE_WITH_CODE (
+	CamelNNTPStore, camel_nntp_store, CAMEL_TYPE_DISCO_STORE,
+	G_IMPLEMENT_INTERFACE (
+		G_TYPE_INITABLE, camel_nntp_store_initable_init))
 
 static gint
 camel_nntp_try_authenticate (CamelNNTPStore *store,
                              GCancellable *cancellable,
                              GError **error)
 {
-	CamelService *service = (CamelService *) store;
-	CamelSession *session = camel_service_get_session (service);
+	CamelService *service;
+	CamelSession *session;
+	CamelURL *url;
 	gint ret;
 	gchar *line = NULL;
 	GError *local_error = NULL;
 
-	if (!service->url->user) {
+	service = CAMEL_SERVICE (store);
+	url = camel_service_get_camel_url (service);
+	session = camel_service_get_session (service);
+
+	if (!url->user) {
 		g_set_error (
 			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
 			_("Authentication requested but no username provided"));
@@ -75,11 +88,11 @@ camel_nntp_try_authenticate (CamelNNTPStore *store,
 	}
 
 	/* if nessecary, prompt for the password */
-	if (!service->url->passwd) {
+	if (!url->passwd) {
 		gchar *prompt, *base;
 	retry:
 		base = camel_session_build_password_prompt (
-			"NNTP", service->url->user, service->url->host);
+			"NNTP", url->user, url->host);
 		if (line) {
 			gchar *top = g_markup_printf_escaped (
 				_("Cannot authenticate to server: %s"), line);
@@ -91,22 +104,22 @@ camel_nntp_try_authenticate (CamelNNTPStore *store,
 			base = NULL;
 		}
 
-		service->url->passwd =
+		url->passwd =
 			camel_session_get_password (session, service, NULL,
 						    prompt, "password", CAMEL_SESSION_PASSWORD_SECRET | (store->password_reprompt ? CAMEL_SESSION_PASSWORD_REPROMPT : 0), error);
 		g_free (prompt);
 		g_free (base);
 
-		if (!service->url->passwd)
+		if (!url->passwd)
 			return -1;
 
 		store->password_reprompt = FALSE;
 	}
 
 	/* now, send auth info (currently, only authinfo user/pass is supported) */
-	ret = camel_nntp_raw_command(store, cancellable, &local_error, &line, "authinfo user %s", service->url->user);
+	ret = camel_nntp_raw_command(store, cancellable, &local_error, &line, "authinfo user %s", url->user);
 	if (ret == NNTP_AUTH_CONTINUE)
-		ret = camel_nntp_raw_command(store, cancellable, &local_error, &line, "authinfo pass %s", service->url->passwd);
+		ret = camel_nntp_raw_command(store, cancellable, &local_error, &line, "authinfo pass %s", url->passwd);
 
 	if (ret != NNTP_AUTH_ACCEPTED) {
 		if (ret != -1) {
@@ -118,8 +131,8 @@ camel_nntp_try_authenticate (CamelNNTPStore *store,
 
 			/* To force password reprompt */
 			store->password_reprompt = TRUE;
-			g_free (service->url->passwd);
-			service->url->passwd = NULL;
+			g_free (url->passwd);
+			url->passwd = NULL;
 			goto retry;
 		}
 		return -1;
@@ -177,7 +190,6 @@ nntp_store_finalize (GObject *object)
 	struct _xover_header *xover, *xn;
 
 	g_free (nntp_store->base_url);
-	g_free (nntp_store->storage_path);
 
 	xover = nntp_store->xover;
 	while (xover) {
@@ -196,6 +208,39 @@ nntp_can_work_offline (CamelDiscoStore *store)
 	return TRUE;
 }
 
+static gint
+check_capabilities (CamelNNTPStore *store,
+             GCancellable *cancellable,
+             GError **error)
+{
+	gint ret;
+	gchar *line;
+	guint len;
+
+	store->capabilities = 0;
+
+	ret = camel_nntp_raw_command_auth (store, cancellable, error, &line, "CAPABILITIES");
+	if (ret != 101)
+		return -1;
+
+	while ((ret = camel_nntp_stream_line (store->stream, (guchar **) &line, &len, cancellable, error)) > 0) {
+		while (len > 0 && g_ascii_isspace (*line)) {
+			line++;
+			len--;
+		}
+
+		if (len == 4 && g_ascii_strncasecmp (line, "OVER", len) == 0)
+			store->capabilities |= NNTP_CAPABILITY_OVER;
+
+		if (len == 1 && g_ascii_strncasecmp (line, ".", len) == 0) {
+			ret = 0;
+			break;
+		}
+	}
+
+	return ret;
+}
+
 static struct {
 	const gchar *name;
 	gint type;
@@ -285,36 +330,41 @@ connect_to_server (CamelService *service,
 	CamelNNTPStore *store = (CamelNNTPStore *) service;
 	CamelDiscoStore *disco_store = (CamelDiscoStore*) service;
 	CamelSession *session;
+	CamelURL *url;
 	gchar *socks_host;
 	gint socks_port;
 	CamelStream *tcp_stream;
+	const gchar *user_data_dir;
 	gboolean retval = FALSE;
 	guchar *buf;
 	guint len;
 	gchar *path;
 
-	camel_service_lock (CAMEL_SERVICE (store), CAMEL_SERVICE_REC_CONNECT_LOCK);
+	url = camel_service_get_camel_url (service);
+	session = camel_service_get_session (service);
+	user_data_dir = camel_service_get_user_data_dir (service);
+
+	camel_service_lock (service, CAMEL_SERVICE_REC_CONNECT_LOCK);
 
 	if (ssl_mode != MODE_CLEAR) {
 #ifdef CAMEL_HAVE_SSL
 		if (ssl_mode == MODE_TLS) {
-			tcp_stream = camel_tcp_stream_ssl_new_raw (service->session, service->url->host, STARTTLS_FLAGS);
+			tcp_stream = camel_tcp_stream_ssl_new_raw (session, url->host, STARTTLS_FLAGS);
 		} else {
-			tcp_stream = camel_tcp_stream_ssl_new (service->session, service->url->host, SSL_PORT_FLAGS);
+			tcp_stream = camel_tcp_stream_ssl_new (session, url->host, SSL_PORT_FLAGS);
 		}
 #else
 		g_set_error (
 			error, CAMEL_SERVICE_ERROR,
 			CAMEL_SERVICE_ERROR_UNAVAILABLE,
 			_("Could not connect to %s: %s"),
-			service->url->host, _("SSL unavailable"));
+			url->host, _("SSL unavailable"));
 		goto fail;
 #endif /* CAMEL_HAVE_SSL */
 	} else {
 		tcp_stream = camel_tcp_stream_raw_new ();
 	}
 
-	session = camel_service_get_session (service);
 	camel_session_get_socks_proxy (session, &socks_host, &socks_port);
 
 	if (socks_host) {
@@ -327,7 +377,7 @@ connect_to_server (CamelService *service,
 		fallback_port, cancellable, error) == -1) {
 		g_prefix_error (
 			error, _("Could not connect to %s: "),
-			service->url->host);
+			url->host);
 		g_object_unref (tcp_stream);
 
 		goto fail;
@@ -340,7 +390,7 @@ connect_to_server (CamelService *service,
 	if (camel_nntp_stream_line (store->stream, &buf, &len, cancellable, error) == -1) {
 		g_prefix_error (
 			error, _("Could not read greeting from %s: "),
-			service->url->host);
+			url->host);
 
 		g_object_unref (store->stream);
 		store->stream = NULL;
@@ -353,7 +403,7 @@ connect_to_server (CamelService *service,
 		g_set_error (
 			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
 			_("NNTP server %s returned error code %d: %s"),
-			service->url->host, len, buf);
+			url->host, len, buf);
 
 		g_object_unref (store->stream);
 		store->stream = NULL;
@@ -362,8 +412,7 @@ connect_to_server (CamelService *service,
 	}
 
 	/* if we have username, try it here */
-	if (service->url->user != NULL
-	    && service->url->user[0]
+	if (url->user != NULL && url->user[0]
 	    && camel_nntp_try_authenticate (store, cancellable, error) != NNTP_AUTH_ACCEPTED)
 		goto fail;
 
@@ -376,7 +425,7 @@ connect_to_server (CamelService *service,
 		goto fail;
 
 	if (!disco_store->diary) {
-		path = g_build_filename (store->storage_path, ".ev-journal", NULL);
+		path = g_build_filename (user_data_dir, ".ev-journal", NULL);
 		disco_store->diary = camel_disco_diary_new (disco_store, path, error);
 		g_free (path);
 	}
@@ -387,7 +436,7 @@ connect_to_server (CamelService *service,
 	store->current_folder = NULL;
 
  fail:
-	camel_service_unlock (CAMEL_SERVICE (store), CAMEL_SERVICE_REC_CONNECT_LOCK);
+	camel_service_unlock (service, CAMEL_SERVICE_REC_CONNECT_LOCK);
 	return retval;
 }
 
@@ -409,12 +458,17 @@ nntp_connect_online (CamelService *service,
                      GCancellable *cancellable,
                      GError **error)
 {
+	CamelNNTPStore *store = CAMEL_NNTP_STORE (service);
+	CamelURL *url;
 	const gchar *ssl_mode;
 	gint mode, i;
 	gchar *serv;
 	gint fallback_port;
+	GError *local_error = NULL;
 
-	if ((ssl_mode = camel_url_get_param (service->url, "use_ssl"))) {
+	url = camel_service_get_camel_url (service);
+
+	if ((ssl_mode = camel_url_get_param (url, "use_ssl"))) {
 		for (i = 0; ssl_options[i].value; i++)
 			if (!strcmp (ssl_options[i].value, ssl_mode))
 				break;
@@ -427,14 +481,38 @@ nntp_connect_online (CamelService *service,
 		fallback_port = NNTP_PORT;
 	}
 
-	if (service->url->port) {
+	if (url->port) {
 		serv = g_alloca (16);
-		sprintf (serv, "%d", service->url->port);
+		sprintf (serv, "%d", url->port);
 		fallback_port = 0;
 	}
 
+	if (!connect_to_server (
+		service, url->host, serv,
+		fallback_port, mode, cancellable, error))
+		return FALSE;
+
+	if (check_capabilities (store, cancellable, &local_error) != -1)
+		return TRUE;
+
+	if (local_error)
+		g_error_free (local_error);
+
+	store->capabilities = 0;
+
+	/* disconnect and reconnect without capability check */
+	camel_service_lock (CAMEL_SERVICE (store), CAMEL_SERVICE_REC_CONNECT_LOCK);
+
+	if (store->stream)
+		g_object_unref (store->stream);
+	store->stream = NULL;
+	g_free (store->current_folder);
+	store->current_folder = NULL;
+
+	camel_service_unlock (CAMEL_SERVICE (store), CAMEL_SERVICE_REC_CONNECT_LOCK);
+
 	return connect_to_server (
-		service, service->url->host, serv,
+		service, url->host, serv,
 		fallback_port, mode, cancellable, error);
 }
 
@@ -445,14 +523,14 @@ nntp_connect_offline (CamelService *service,
 {
 	CamelNNTPStore *nntp_store = CAMEL_NNTP_STORE (service);
 	CamelDiscoStore *disco_store = (CamelDiscoStore *) nntp_store;
+	const gchar *user_data_dir;
 	gchar *path;
 
-	if (nntp_store->storage_path == NULL)
-		return FALSE;
+	user_data_dir = camel_service_get_user_data_dir (service);
 
 	/* setup store-wide cache */
 	if (nntp_store->cache == NULL) {
-		nntp_store->cache = camel_data_cache_new (nntp_store->storage_path, error);
+		nntp_store->cache = camel_data_cache_new (user_data_dir, error);
 		if (nntp_store->cache == NULL)
 			return FALSE;
 
@@ -464,7 +542,7 @@ nntp_connect_offline (CamelService *service,
 	if (disco_store->diary)
 		return TRUE;
 
-	path = g_build_filename (nntp_store->storage_path, ".ev-journal", NULL);
+	path = g_build_filename (user_data_dir, ".ev-journal", NULL);
 	disco_store->diary = camel_disco_diary_new (disco_store, path, error);
 	g_free (path);
 
@@ -517,10 +595,14 @@ nntp_disconnect_offline (CamelService *service,
 static gchar *
 nntp_store_get_name (CamelService *service, gboolean brief)
 {
+	CamelURL *url;
+
+	url = camel_service_get_camel_url (service);
+
 	if (brief)
-		return g_strdup_printf ("%s", service->url->host);
+		return g_strdup_printf ("%s", url->host);
 	else
-		return g_strdup_printf (_("USENET News via %s"), service->url->host);
+		return g_strdup_printf (_("USENET News via %s"), url->host);
 
 }
 
@@ -593,57 +675,44 @@ nntp_newsgroup_name_short (const gchar *name)
  */
 
 static CamelFolderInfo *
-nntp_folder_info_from_store_info (CamelNNTPStore *store, gboolean short_notation, CamelStoreInfo *si)
+nntp_folder_info_from_store_info (CamelNNTPStore *store,
+                                  gboolean short_notation,
+                                  CamelStoreInfo *si)
 {
-	CamelURL *base_url = ((CamelService *) store)->url;
 	CamelFolderInfo *fi;
-	CamelURL *url;
-	gchar *path;
 
 	fi = camel_folder_info_new ();
 	fi->full_name = g_strdup (si->path);
 
 	if (short_notation)
-		fi->name = nntp_newsgroup_name_short (si->path);
+		fi->display_name = nntp_newsgroup_name_short (si->path);
 	else
-		fi->name = g_strdup (si->path);
+		fi->display_name = g_strdup (si->path);
 
 	fi->unread = si->unread;
 	fi->total = si->total;
 	fi->flags = si->flags;
-	path = alloca (strlen (fi->full_name)+2);
-	sprintf(path, "/%s", fi->full_name);
-	url = camel_url_new_with_base (base_url, path);
-	fi->uri = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
-	camel_url_free (url);
 
 	return fi;
 }
 
 static CamelFolderInfo *
-nntp_folder_info_from_name (CamelNNTPStore *store, gboolean short_notation, const gchar *name)
+nntp_folder_info_from_name (CamelNNTPStore *store,
+                            gboolean short_notation,
+                            const gchar *name)
 {
-	CamelURL *base_url = ((CamelService *)store)->url;
 	CamelFolderInfo *fi;
-	CamelURL *url;
-	gchar *path;
 
 	fi = camel_folder_info_new ();
 	fi->full_name = g_strdup (name);
 
 	if (short_notation)
-		fi->name = nntp_newsgroup_name_short (name);
+		fi->display_name = nntp_newsgroup_name_short (name);
 	else
-		fi->name = g_strdup (name);
+		fi->display_name = g_strdup (name);
 
 	fi->unread = -1;
 
-	path = alloca (strlen (fi->full_name)+2);
-	sprintf(path, "/%s", fi->full_name);
-	url = camel_url_new_with_base (base_url, path);
-	fi->uri = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
-	camel_url_free (url);
-
 	return fi;
 }
 
@@ -651,20 +720,22 @@ nntp_folder_info_from_name (CamelNNTPStore *store, gboolean short_notation, cons
 static CamelNNTPStoreInfo *
 nntp_store_info_update (CamelNNTPStore *store, gchar *line)
 {
-	CamelStoreSummary *summ = (CamelStoreSummary *)store->summary;
-	CamelURL *base_url = ((CamelService *)store)->url;
+	CamelStoreSummary *summ = (CamelStoreSummary *) store->summary;
+	CamelURL *base_url;
 	CamelNNTPStoreInfo *si, *fsi;
 	CamelURL *url;
 	gchar *relpath, *tmp;
 	guint32 last = 0, first = 0, new = 0;
 
+	base_url = camel_service_get_camel_url (CAMEL_SERVICE (store));
+
 	tmp = strchr (line, ' ');
 	if (tmp)
 		*tmp++ = 0;
 
-	fsi = si = (CamelNNTPStoreInfo *)camel_store_summary_path ((CamelStoreSummary *)store->summary, line);
+	fsi = si = (CamelNNTPStoreInfo *) camel_store_summary_path ((CamelStoreSummary *) store->summary, line);
 	if (si == NULL) {
-		si = (CamelNNTPStoreInfo*)camel_store_summary_info_new (summ);
+		si = (CamelNNTPStoreInfo*) camel_store_summary_info_new (summ);
 
 		relpath = g_alloca (strlen (line)+2);
 		sprintf(relpath, "/%s", line);
@@ -674,7 +745,7 @@ nntp_store_info_update (CamelNNTPStore *store, gchar *line)
 
 		si->info.path = g_strdup (line);
 		si->full_name = g_strdup (line); /* why do we keep this? */
-		camel_store_summary_add ((CamelStoreSummary *)store->summary, &si->info);
+		camel_store_summary_add ((CamelStoreSummary *) store->summary, &si->info);
 	} else {
 		first = si->first;
 		last = si->last;
@@ -705,9 +776,9 @@ nntp_store_info_update (CamelNNTPStore *store, gchar *line)
 	si->first = first;
 
 	if (fsi)
-		camel_store_summary_info_free ((CamelStoreSummary *)store->summary, &fsi->info);
+		camel_store_summary_info_free ((CamelStoreSummary *) store->summary, &fsi->info);
 	else			/* TODO see if we really did touch it */
-		camel_store_summary_touch ((CamelStoreSummary *)store->summary);
+		camel_store_summary_touch ((CamelStoreSummary *) store->summary);
 
 	return si;
 }
@@ -740,7 +811,7 @@ nntp_store_get_subscribed_folder_info (CamelNNTPStore *store,
 
 				folder = (CamelNNTPFolder *)
 					camel_store_get_folder_sync (
-					(CamelStore *)store, si->path,
+					(CamelStore *) store, si->path,
 					0, cancellable, NULL);
 				if (folder) {
 					CamelFolderChangeInfo *changes = NULL;
@@ -802,7 +873,10 @@ tree_insert (CamelFolderInfo *root, CamelFolderInfo *last, CamelFolderInfo *fi)
 }
 /* returns new root */
 static CamelFolderInfo *
-nntp_push_to_hierarchy (CamelURL *base_url, CamelFolderInfo *root, CamelFolderInfo *pfi, GHashTable *known)
+nntp_push_to_hierarchy (CamelNNTPStore *store,
+                        CamelFolderInfo *root,
+                        CamelFolderInfo *pfi,
+                        GHashTable *known)
 {
 	CamelFolderInfo *fi, *last = NULL, *kfi;
 	gchar *name, *dot;
@@ -818,21 +892,15 @@ nntp_push_to_hierarchy (CamelURL *base_url, CamelFolderInfo *root, CamelFolderIn
 
 		kfi = g_hash_table_lookup (known, pfi->full_name);
 		if (!kfi) {
-			gchar *path;
-			CamelURL *url;
-
 			fi = camel_folder_info_new ();
 			fi->full_name = g_strdup (pfi->full_name);
-			fi->name = g_strdup (name);
+			fi->display_name = g_strdup (name);
 
 			fi->unread = 0;
 			fi->total = 0;
-			fi->flags = CAMEL_FOLDER_NOSELECT | CAMEL_FOLDER_CHILDREN;
-			path = alloca (strlen (fi->full_name) + 2);
-			sprintf (path, "/%s", fi->full_name);
-			url = camel_url_new_with_base (base_url, path);
-			fi->uri = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
-			camel_url_free (url);
+			fi->flags =
+				CAMEL_FOLDER_NOSELECT |
+				CAMEL_FOLDER_CHILDREN;
 
 			g_hash_table_insert (known, fi->full_name, fi);
 			root = tree_insert (root, last, fi);
@@ -845,8 +913,8 @@ nntp_push_to_hierarchy (CamelURL *base_url, CamelFolderInfo *root, CamelFolderIn
 		name = dot + 1;
 	}
 
-	g_free (pfi->name);
-	pfi->name = g_strdup (name);
+	g_free (pfi->display_name);
+	pfi->display_name = g_strdup (name);
 
 	return tree_insert (root, last, pfi);
 }
@@ -855,7 +923,10 @@ nntp_push_to_hierarchy (CamelURL *base_url, CamelFolderInfo *root, CamelFolderIn
  * get folder info, using the information in our StoreSummary
  */
 static CamelFolderInfo *
-nntp_store_get_cached_folder_info (CamelNNTPStore *store, const gchar *orig_top, guint flags, GError **error)
+nntp_store_get_cached_folder_info (CamelNNTPStore *store,
+                                   const gchar *orig_top,
+                                   guint flags,
+                                   GError **error)
 {
 	gint i;
 	gint subscribed_or_flag = (flags & CAMEL_STORE_FOLDER_INFO_SUBSCRIBED) ? 0 : 1,
@@ -880,8 +951,8 @@ nntp_store_get_cached_folder_info (CamelNNTPStore *store, const gchar *orig_top,
 				if (!fi)
 					continue;
 				if (store->folder_hierarchy_relative) {
-					g_free (fi->name);
-					fi->name = g_strdup (si->path + ((toplen == 1) ? 0 : toplen));
+					g_free (fi->display_name);
+					fi->display_name = g_strdup (si->path + ((toplen == 1) ? 0 : toplen));
 				}
 			} else {
 				/* apparently, this is an indirect subitem. if it's not a subitem of
@@ -898,8 +969,8 @@ nntp_store_get_cached_folder_info (CamelNNTPStore *store, const gchar *orig_top,
 
 					fi->flags |= CAMEL_FOLDER_NOSELECT;
 					if (store->folder_hierarchy_relative) {
-						g_free (fi->name);
-						fi->name = g_strdup (tmpname + ((toplen==1) ? 0 : toplen));
+						g_free (fi->display_name);
+						fi->display_name = g_strdup (tmpname + ((toplen==1) ? 0 : toplen));
 					}
 					g_free (tmpname);
 				} else {
@@ -917,7 +988,7 @@ nntp_store_get_cached_folder_info (CamelNNTPStore *store, const gchar *orig_top,
 
 			if (is_folder_list) {
 				/* create a folder hierarchy rather than a flat list */
-				first = nntp_push_to_hierarchy (((CamelService *)store)->url, first, fi, known);
+				first = nntp_push_to_hierarchy (store, first, fi, known);
 			} else {
 				if (last)
 					last->next = fi;
@@ -927,10 +998,10 @@ nntp_store_get_cached_folder_info (CamelNNTPStore *store, const gchar *orig_top,
 			}
 		} else if (subscribed_or_flag && first) {
 			/* we have already added subitems, but this item is no longer a subitem */
-			camel_store_summary_info_free ((CamelStoreSummary *)store->summary, si);
+			camel_store_summary_info_free ((CamelStoreSummary *) store->summary, si);
 			break;
 		}
-		camel_store_summary_info_free ((CamelStoreSummary *)store->summary, si);
+		camel_store_summary_info_free ((CamelStoreSummary *) store->summary, si);
 	}
 
 	g_hash_table_destroy (known);
@@ -1043,7 +1114,7 @@ nntp_store_get_folder_info_all (CamelNNTPStore *nntp_store,
 			}
 
 			all = g_hash_table_new (g_str_hash, g_str_equal);
-			for (i = 0; (si = (CamelNNTPStoreInfo *)camel_store_summary_index ((CamelStoreSummary *)nntp_store->summary, i)); i++)
+			for (i = 0; (si = (CamelNNTPStoreInfo *) camel_store_summary_index ((CamelStoreSummary *) nntp_store->summary, i)); i++)
 				g_hash_table_insert (all, si->info.path, si);
 
 			while ((ret = camel_nntp_stream_line (nntp_store->stream, &line, &len, cancellable, error)) > 0) {
@@ -1274,33 +1345,34 @@ nntp_can_refresh_folder (CamelStore *store, CamelFolderInfo *info, GError **erro
 	return TRUE;
 }
 
-/* construction function in which we set some basic store properties */
 static gboolean
-nntp_construct (CamelService *service, CamelSession *session,
-		CamelProvider *provider, CamelURL *url,
-		GError **error)
+nntp_store_initable_init (GInitable *initable,
+                          GCancellable *cancellable,
+                          GError **error)
 {
-	CamelServiceClass *service_class;
-	CamelNNTPStore *nntp_store = CAMEL_NNTP_STORE (service);
+	CamelNNTPStore *nntp_store;
+	CamelService *service;
 	CamelURL *summary_url;
+	CamelURL *url;
+	const gchar *user_data_dir;
 	gchar *tmp;
 
-	/* construct the parent first */
-	service_class = CAMEL_SERVICE_CLASS (camel_nntp_store_parent_class);
-	if (!service_class->construct (service, session, provider, url, error))
+	nntp_store = CAMEL_NNTP_STORE (initable);
+
+	/* Chain up to parent interface's init() method. */
+	if (!parent_initable_interface->init (initable, cancellable, error))
 		return FALSE;
 
-	/* find out the storage path, base url */
-	nntp_store->storage_path = camel_session_get_storage_path (session, service, error);
-	if (!nntp_store->storage_path)
-		return FALSE;
+	service = CAMEL_SERVICE (initable);
+	url = camel_service_get_camel_url (service);
+	user_data_dir = camel_service_get_user_data_dir (service);
 
 	/* FIXME */
-	nntp_store->base_url = camel_url_to_string (service->url, (CAMEL_URL_HIDE_PASSWORD |
-								   CAMEL_URL_HIDE_PARAMS |
-								   CAMEL_URL_HIDE_AUTH));
+	nntp_store->base_url = camel_url_to_string (
+		url, CAMEL_URL_HIDE_PASSWORD |
+		CAMEL_URL_HIDE_PARAMS | CAMEL_URL_HIDE_AUTH);
 
-	tmp = g_build_filename (nntp_store->storage_path, ".ev-store-summary", NULL);
+	tmp = g_build_filename (user_data_dir, ".ev-store-summary", NULL);
 	nntp_store->summary = camel_nntp_store_summary_new ();
 	camel_store_summary_set_filename ((CamelStoreSummary *) nntp_store->summary, tmp);
 	summary_url = camel_url_new (nntp_store->base_url, NULL);
@@ -1308,7 +1380,7 @@ nntp_construct (CamelService *service, CamelSession *session,
 	g_free (tmp);
 
 	camel_url_free (summary_url);
-	camel_store_summary_load ((CamelStoreSummary *)nntp_store->summary);
+	camel_store_summary_load ((CamelStoreSummary *) nntp_store->summary);
 
 	/* get options */
 	if (camel_url_get_param (url, "show_short_notation"))
@@ -1321,7 +1393,7 @@ nntp_construct (CamelService *service, CamelSession *session,
 		nntp_store->folder_hierarchy_relative = FALSE;
 
 	/* setup store-wide cache */
-	nntp_store->cache = camel_data_cache_new (nntp_store->storage_path, error);
+	nntp_store->cache = camel_data_cache_new (user_data_dir, error);
 	if (nntp_store->cache == NULL)
 		return FALSE;
 
@@ -1347,7 +1419,6 @@ camel_nntp_store_class_init (CamelNNTPStoreClass *class)
 	object_class->finalize = nntp_store_finalize;
 
 	service_class = CAMEL_SERVICE_CLASS (class);
-	service_class->construct = nntp_construct;
 	service_class->get_name = nntp_store_get_name;
 	service_class->query_auth_types_sync = nntp_store_query_auth_types_sync;
 
@@ -1375,6 +1446,14 @@ camel_nntp_store_class_init (CamelNNTPStoreClass *class)
 	disco_store_class->get_folder_info_offline = nntp_get_folder_info_offline;
 }
 
+static void
+camel_nntp_store_initable_init (GInitableIface *interface)
+{
+	parent_initable_interface = g_type_interface_peek_parent (interface);
+
+	interface->init = nntp_store_initable_init;
+}
+
 static void
 camel_nntp_store_init (CamelNNTPStore *nntp_store)
 {
@@ -1382,7 +1461,7 @@ camel_nntp_store_init (CamelNNTPStore *nntp_store)
 
 	store->flags = CAMEL_STORE_SUBSCRIPTIONS;
 
-	nntp_store->mem = (CamelStreamMem *)camel_stream_mem_new ();
+	nntp_store->mem = (CamelStreamMem *) camel_stream_mem_new ();
 
 	nntp_store->priv = G_TYPE_INSTANCE_GET_PRIVATE (
 		nntp_store, CAMEL_TYPE_NNTP_STORE, CamelNNTPStorePrivate);
@@ -1420,7 +1499,7 @@ camel_nntp_raw_commandv (CamelNNTPStore *store,
 			switch (c) {
 			case 's':
 				s = va_arg (ap, gchar *);
-				camel_stream_write ((CamelStream *)store->mem, s, strlen (s), NULL, NULL);
+				camel_stream_write ((CamelStream *) store->mem, s, strlen (s), NULL, NULL);
 				break;
 			case 'd':
 				d = va_arg (ap, gint);
@@ -1543,7 +1622,7 @@ camel_nntp_command (CamelNNTPStore *store,
 	guint u;
 	GError *local_error = NULL;
 
-	if (((CamelDiscoStore *)store)->status == CAMEL_DISCO_STORE_OFFLINE) {
+	if (((CamelDiscoStore *) store)->status == CAMEL_DISCO_STORE_OFFLINE) {
 		g_set_error (
 			error, CAMEL_SERVICE_ERROR,
 			CAMEL_SERVICE_ERROR_NOT_CONNECTED,
