@@ -72,7 +72,6 @@ stream_fill (CamelPOP3Stream *is,
              GError **error)
 {
 	gint left = 0;
-	GError *local_error = NULL;
 
 	if (is->source) {
 		left = is->end - is->ptr;
@@ -82,12 +81,7 @@ stream_fill (CamelPOP3Stream *is,
 		left = camel_stream_read (
 			is->source, (gchar *) is->end,
 			CAMEL_POP3_STREAM_SIZE - (is->end - is->buf),
-			cancellable, &local_error);
-		if (local_error) {
-			dd (printf ("POP3_STREAM_FILL: Failed to read bytes: %s\n", local_error->message));
-			g_propagate_error (error, local_error);
-		}
-
+			cancellable, error);
 		if (left > 0) {
 			is->end += left;
 			is->end[0] = '\n';
@@ -106,7 +100,7 @@ stream_read (CamelStream *stream,
              GCancellable *cancellable,
              GError **error)
 {
-	CamelPOP3Stream *is = (CamelPOP3Stream *)stream;
+	CamelPOP3Stream *is = (CamelPOP3Stream *) stream;
 	gchar *o, *oe;
 	guchar *p, *e, c;
 	gint state;
@@ -182,7 +176,7 @@ stream_write (CamelStream *stream,
               GCancellable *cancellable,
               GError **error)
 {
-	CamelPOP3Stream *is = (CamelPOP3Stream *)stream;
+	CamelPOP3Stream *is = (CamelPOP3Stream *) stream;
 
 	if (strncmp (buffer, "PASS ", 5) != 0)
 		dd (printf ("POP3_STREAM_WRITE (%d):\n%.*s\n", (gint)n, (gint)n, buffer));
@@ -213,7 +207,7 @@ stream_flush (CamelStream *stream,
 static gboolean
 stream_eos (CamelStream *stream)
 {
-	CamelPOP3Stream *is = (CamelPOP3Stream *)stream;
+	CamelPOP3Stream *is = (CamelPOP3Stream *) stream;
 
 	return is->mode != CAMEL_POP3_STREAM_DATA;
 }
@@ -276,7 +270,7 @@ camel_pop3_stream_new (CamelStream *source)
 	is = g_object_new (CAMEL_TYPE_POP3_STREAM, NULL);
 	is->source = g_object_ref (source);
 
-	return (CamelStream *)is;
+	return (CamelStream *) is;
 }
 
 /* Get one line from the pop3 stream */
