@@ -11,17 +11,14 @@ static const gchar *remote_providers[] = {
 	"IMAP_TEST_URL",
 };
 
-gint main(gint argc, gchar **argv)
+gint main (gint argc, gchar **argv)
 {
 	CamelSession *session;
-	CamelException *ex;
 	gint i;
 	gchar *path;
 
-	camel_test_init(argc, argv);
-	camel_test_provider_init(1, imap_drivers);
-
-	ex = camel_exception_new();
+	camel_test_init (argc, argv);
+	camel_test_provider_init (1, imap_drivers);
 
 	/* clear out any camel-test data */
 	system("/bin/rm -rf /tmp/camel-test");
@@ -31,21 +28,20 @@ gint main(gint argc, gchar **argv)
 	/* todo: cross-check everything with folder_info checks as well */
 	/* todo: subscriptions? */
 	for (i = 0; i < G_N_ELEMENTS (remote_providers); i++) {
-		path = getenv(remote_providers[i]);
+		path = getenv (remote_providers[i]);
 
 		if (path == NULL) {
 			printf("Aborted (ignored).\n");
 			printf("Set '%s', to re-run test.\n", remote_providers[i]);
 			/* tells make check to ignore us in the total count */
-			_exit(77);
+			_exit (77);
 		}
 		/*camel_test_nonfatal("The IMAP code is just rooted");*/
-		test_folder_basic(session, path, FALSE, FALSE);
+		test_folder_basic (session, path, FALSE, FALSE);
 		/*camel_test_fatal();*/
 	}
 
 	g_object_unref (session);
-	camel_exception_free(ex);
 
 	return 0;
 }
