@@ -29,7 +29,7 @@
 #include <glib/gi18n-lib.h>
 #include <libebook/e-book.h>
 #include <libedataserverui/e-passwords.h>
-#include "libedataserver/e-url.h"
+#include <libedataserver/e-url.h>
 #include "e-book-auth-util.h"
 
 static void addressbook_authenticate (EBook *book, gboolean previous_failure,
@@ -163,7 +163,7 @@ addressbook_authenticate (EBook *book, gboolean previous_failure, ESource *sourc
 	const gchar *component_name;
 	gchar *password = NULL;
 	const gchar *uri = e_book_get_uri (book);
-        gchar *stripped_uri = remove_parameters_from_uri (uri);
+	gchar *stripped_uri = remove_parameters_from_uri (uri);
 	const gchar *auth_domain = e_source_get_property (source, "auth-domain");
 
 	component_name = auth_domain ? auth_domain : "Addressbook";
@@ -256,9 +256,14 @@ load_source_cb (EBook *book, const GError *error, gpointer closure)
 	if (!error && book != NULL) {
 		const gchar *auth;
 
+		/* Listen for "auth-required" signals regardless of
+		 * whether the ESource claims to require authentication. */
+		g_signal_connect (
+			book, "auth-required",
+			G_CALLBACK (auth_required_cb), NULL);
+
 		auth = e_source_get_property (load_source_data->source, "auth");
 		if (auth && strcmp (auth, "none")) {
-			g_signal_connect (book, "auth_required", (GCallback) auth_required_cb, NULL);
 
 			if (e_book_is_online (book)) {
 				addressbook_authenticate (book, FALSE, load_source_data->source,
