@@ -21,10 +21,15 @@
  * Author: Hans Petter Jansson <hpj@novell.com>
  */
 
+#ifdef GTK_DISABLE_DEPRECATED
+#undef GTK_DISABLE_DEPRECATED
+#endif
+
 #include <config.h>
 #include <string.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n-lib.h>
+#include <gconf/gconf-client.h>
 #include <libedataserverui/e-source-combo-box.h>
 #include <libedataserverui/e-destination-store.h>
 #include <libedataserverui/e-contact-store.h>
@@ -426,7 +431,7 @@ e_name_selector_dialog_finalize (GObject *object)
 
 	priv = E_NAME_SELECTOR_DIALOG (object)->priv;
 
-	g_slist_foreach (priv->user_query_fields, (GFunc)g_free, NULL);
+	g_slist_foreach (priv->user_query_fields, (GFunc) g_free, NULL);
 	g_slist_free (priv->user_query_fields);
 
 	g_array_free (priv->sections, TRUE);
