@@ -24,6 +24,7 @@
 #include <config.h>
 #include <string.h>
 #include <glib/gi18n-lib.h>
+#include <gconf/gconf-client.h>
 
 #include <camel/camel.h>
 #include <libebook/e-book.h>
@@ -128,7 +129,7 @@ name_selector_entry_dispose (GObject *object)
 		priv->contact_store = NULL;
 	}
 
-	g_slist_foreach (priv->user_query_fields, (GFunc)g_free, NULL);
+	g_slist_foreach (priv->user_query_fields, (GFunc) g_free, NULL);
 	g_slist_free (priv->user_query_fields);
 	priv->user_query_fields = NULL;
 
@@ -1371,7 +1372,7 @@ user_delete_text (ENameSelectorEntry *name_selector_entry, gint start_pos, gint
 		gboolean sel=FALSE;
 
 		if (destination)
-			email = e_destination_get_address (destination);
+			email = e_destination_get_textrep (destination, TRUE);
 
 		if (!email || !*email)
 			continue;
@@ -1444,7 +1445,7 @@ user_delete_text (ENameSelectorEntry *name_selector_entry, gint start_pos, gint
 			const gchar *email=NULL;
 
 			if (destination1)
-				email = e_destination_get_address (destination1);
+				email = e_destination_get_textrep (destination1, TRUE);
 
 			if (email && *email) {
 
@@ -1826,7 +1827,7 @@ contact_layout_pixbuffer (GtkCellLayout *cell_layout, GtkCellRenderer *cell, Gtk
 		GdkPixbufLoader *loader;
 
 		loader = gdk_pixbuf_loader_new ();
-		if (gdk_pixbuf_loader_write (loader, (guchar *)photo->data.inlined.data, photo->data.inlined.length, NULL) &&
+		if (gdk_pixbuf_loader_write (loader, (guchar *) photo->data.inlined.data, photo->data.inlined.length, NULL) &&
 		    gdk_pixbuf_loader_close (loader, NULL)) {
 			pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
 			if (pixbuf)
@@ -2338,33 +2339,6 @@ editor_closed_cb (GtkWidget *editor, gpointer data)
 	g_object_unref (name_selector_entry);
 }
 
-/* To parse something like...
- * =?UTF-8?Q?=E0=A4=95=E0=A4=95=E0=A4=AC=E0=A5=82=E0=A5=8B=E0=A5=87?=\t\n=?UTF-8?Q?=E0=A4=B0?=\t\n<aa@aa.ccom>
- * and return the decoded representation of name & email parts.
- * */
-static gboolean
-eab_parse_qp_email (const gchar *string, gchar **name, gchar **email)
-{
-        struct _camel_header_address *address;
-        gboolean res = FALSE;
-
-        address = camel_header_address_decode (string, "UTF-8");
-
-        if (!address)
-                return FALSE;
-
-        /* report success only when we have filled both name and email address */
-        if (address->type == CAMEL_HEADER_ADDRESS_NAME  && address->name && *address->name && address->v.addr && *address->v.addr) {
-                *name = g_strdup (address->name);
-                *email = g_strdup (address->v.addr);
-                res = TRUE;
-        }
-
-        camel_header_address_unref (address);
-
-        return res;
-}
-
 static void
 popup_activate_inline_expand (ENameSelectorEntry *name_selector_entry, GtkWidget *menu_item)
 {
@@ -2379,25 +2353,15 @@ popup_activate_inline_expand (ENameSelectorEntry *name_selector_entry, GtkWidget
 	for (dests = e_destination_list_get_dests (destination); dests; dests = dests->next) {
 		const EDestination *dest = dests->data;
 		gchar *sanitized;
-		gchar *name = NULL, *email = NULL, *tofree = NULL;
 
 		if (!dest)
 			continue;
 
-		text = e_destination_get_textrep (dest, TRUE);
-
+		text = e_destination_get_address (dest);
 		if (!text || !*text)
 			continue;
 
-		if (eab_parse_qp_email (text, &name, &email)) {
-			tofree = g_strdup_printf ("%s <%s>", name, email);
-			text = tofree;
-			g_free (name);
-			g_free (email);
-		}
-
 		sanitized = sanitize_string (text);
-		g_free (tofree);
 		if (!sanitized)
 			continue;
 
@@ -2513,7 +2477,7 @@ popup_activate_cut (ENameSelectorEntry *name_selector_entry, GtkWidget *menu_ite
 	GtkClipboard *clipboard;
 
 	destination = name_selector_entry->priv->popup_destination;
-	contact_email =e_destination_get_address (destination);
+	contact_email =e_destination_get_textrep (destination, TRUE);
 
 	g_signal_handlers_block_by_func (name_selector_entry, user_insert_text, name_selector_entry);
 	g_signal_handlers_block_by_func (name_selector_entry, user_delete_text, name_selector_entry);
@@ -2542,7 +2506,7 @@ popup_activate_copy (ENameSelectorEntry *name_selector_entry, GtkWidget *menu_it
 	GtkClipboard *clipboard;
 
 	destination = name_selector_entry->priv->popup_destination;
-	contact_email = e_destination_get_address (destination);
+	contact_email = e_destination_get_textrep (destination, TRUE);
 
 	g_signal_handlers_block_by_func (name_selector_entry, user_insert_text, name_selector_entry);
 	g_signal_handlers_block_by_func (name_selector_entry, user_delete_text, name_selector_entry);
@@ -2626,9 +2590,9 @@ populate_popup (ENameSelectorEntry *name_selector_entry, GtkMenu *menu)
 	if (is_list) {
 		const GList *dests = e_destination_list_get_dests (destination);
 		GList *iter;
-		gint length = g_list_length ((GList *)dests);
+		gint length = g_list_length ((GList *) dests);
 
-		for (iter = (GList *)dests; iter; iter = iter->next) {
+		for (iter = (GList *) dests; iter; iter = iter->next) {
 			EDestination *dest = (EDestination *) iter->data;
 			const gchar *email = e_destination_get_email (dest);
 
@@ -2814,11 +2778,11 @@ copy_or_cut_clipboard (ENameSelectorEntry *name_selector_entry,
 		} else {
 			/* the contact is whole selected */
 			dest = find_destination_by_index (name_selector_entry, index);
-			if (dest && e_destination_get_address (dest)) {
+			if (dest && e_destination_get_textrep (dest, TRUE)) {
 				if (addresses->str && *addresses->str)
 					g_string_append (addresses, ", ");
 
-				g_string_append (addresses, e_destination_get_address (dest));
+				g_string_append (addresses, e_destination_get_textrep (dest, TRUE));
 
 				/* store the 'dest' as a value for the index */
 				g_hash_table_insert (hash, GINT_TO_POINTER (index), dest);
